@@ -48,6 +48,9 @@ if TYPE_CHECKING:
     from fabric_cf.actor.core.apis.abc_slice import ABCSlice
     from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
     from fabric_cf.actor.core.apis.abc_delegation import ABCDelegation
+    from fabric_cf.actor.core.util.reservation_set import ReservationSet
+    from fabric_cf.actor.core.kernel.resource_set import ResourceSet
+    from fabric_cf.actor.core.time.term import Term
 
 
 class ActorType(Enum):
@@ -284,8 +287,7 @@ class ABCActorMixin(ABCActorIdentity, ABCTick, ABCTimerQueue):
 
     @abstractmethod
     def query(self, *, query: dict = None, caller: AuthToken = None,
-              actor_proxy: ABCActorProxy = None, handler: ABCQueryResponseHandler = None,
-              id_token: str = None):
+              actor_proxy: ABCActorProxy = None, handler: ABCQueryResponseHandler = None):
         """
         Processes a query request from the specified caller.
 
@@ -294,7 +296,6 @@ class ABCActorMixin(ABCActorIdentity, ABCTick, ABCTimerQueue):
             caller: caller
             actor_proxy: actor proxy
             handler: handler
-            id_token: id_token
 
         Returns:
             query response
@@ -600,6 +601,18 @@ class ABCActorMixin(ABCActorIdentity, ABCTick, ABCTimerQueue):
             Exception in case of error
         """
 
+    @abstractmethod
+    def register_delegation(self, *, delegation: ABCDelegation):
+        """
+        Registers the delegation with the actor. The delegation must not have been previously
+        registered with the actor: there should be no database record for the delegation.
+
+        Args:
+            delegation: delegation to register
+        Raises:
+            Exception in case of error
+        """
+
     @abstractmethod
     def remove_reservation(self, *, reservation: ABCReservationMixin = None, rid: ID = None):
         """
