@@ -32,6 +32,7 @@ from typing import TYPE_CHECKING, List
 from fabric_mb.message_bus.messages.result_delegation_avro import ResultDelegationAvro
 from fabric_mb.message_bus.messages.result_strings_avro import ResultStringsAvro
 from fabric_mb.message_bus.messages.result_avro import ResultAvro
+from fim.user import GraphFormat
 
 if TYPE_CHECKING:
     from fabric_mb.message_bus.messages.ticket_reservation_avro import TicketReservationAvro
@@ -95,12 +96,11 @@ class ABCClientActorManagementObject(ABC):
         """
 
     @abstractmethod
-    def get_brokers(self, *, caller: AuthToken, broker_id: ID = None, id_token: str = None) -> ResultProxyAvro:
+    def get_brokers(self, *, caller: AuthToken, broker_id: ID = None) -> ResultProxyAvro:
         """
         Get all brokers
         @param caller: caller
         @param broker_id : broker_id
-        @param id_token: id token
         @return list of all the brokers
         """
 
@@ -115,36 +115,33 @@ class ABCClientActorManagementObject(ABC):
 
     @abstractmethod
     def get_broker_query_model(self, *, broker: ID, caller: AuthToken, id_token: str,
-                               level: int) -> ResultBrokerQueryModelAvro:
+                               level: int, graph_format: GraphFormat) -> ResultBrokerQueryModelAvro:
         """
         Get Pool Info
         @param broker : broker ID
         @param caller: caller
         @param id_token: str
         @param level: level of details
+        @param graph_format: Graph Format
         @return pool information
         """
 
     @abstractmethod
-    def claim_delegations(self, *, broker: ID, did: ID, caller: AuthToken,
-                          id_token: str = None) -> ResultDelegationAvro:
+    def claim_delegations(self, *, broker: ID, did: ID, caller: AuthToken) -> ResultDelegationAvro:
         """
         Claim delegations
         @param broker : broker ID
         @param did : delegations ID
         @param caller: caller
-        @param id_token: id token
         @return ResultDelegationAvro
         """
 
     @abstractmethod
-    def reclaim_delegations(self, *, broker: ID, did: ID, caller: AuthToken,
-                            id_token: str = None) -> ResultDelegationAvro:
+    def reclaim_delegations(self, *, broker: ID, did: ID, caller: AuthToken) -> ResultDelegationAvro:
         """
         ReClaim delegations
         @param broker : broker ID
         @param did : delegations ID
         @param caller: caller
-        @param id_token: id token
         @return ResultDelegationAvro
         """
