@@ -31,6 +31,8 @@ from typing import TYPE_CHECKING, List
 
 from fabric_mb.message_bus.messages.delegation_avro import DelegationAvro
 from fabric_mb.message_bus.messages.broker_query_model_avro import BrokerQueryModelAvro
+from fim.user import GraphFormat
+
 from fabric_cf.actor.core.apis.abc_component import ABCComponent
 
 
@@ -104,12 +106,14 @@ class ABCMgmtClientActor(ABCComponent):
         """
 
     @abstractmethod
-    def get_broker_query_model(self, *, broker: ID, id_token: str, level: int) -> BrokerQueryModelAvro:
+    def get_broker_query_model(self, *, broker: ID, id_token: str, level: int,
+                               graph_format: GraphFormat) -> BrokerQueryModelAvro:
         """
         Obtains the resources available at the specified broker
         @param broker broker
         @param id_token identity token generated by Credmgr
         @param level: level of details
+        @param graph_format: Graph Format
         @return BQM
         """
 
@@ -123,21 +127,19 @@ class ABCMgmtClientActor(ABCComponent):
         """
 
     @abstractmethod
-    def claim_delegations(self, *, broker: ID, did: ID, id_token: str = None) -> DelegationAvro:
+    def claim_delegations(self, *, broker: ID, did: ID) -> DelegationAvro:
         """
         Claims delegations exported by the specified broker
         @param broker broker guid
         @param did reservation id
-        @param id_token id token
         @return reservation
         """
 
     @abstractmethod
-    def reclaim_delegations(self, *, broker: ID, did: ID, id_token: str = None) -> DelegationAvro:
+    def reclaim_delegations(self, *, broker: ID, did: ID) -> DelegationAvro:
         """
         Reclaim delegations exported by the specified broker
         @param broker broker guid
         @param did reservation id
-        @param id_token id token
         @return reservation
         """
