@@ -30,25 +30,33 @@ import sys
 import threading
 import traceback
 from datetime import datetime, timedelta
-from logging.handlers import RotatingFileHandler
 from typing import TYPE_CHECKING
 
 import logging
 import os
 
+from fim.graph.neo4j_property_graph import Neo4jGraphImporter
+from fim.graph.resources.abc_arm import ABCARMPropertyGraph
 from fss_utils.jwt_validate import JWTValidator
 
 from fabric_cf.actor.core.common.exceptions import InitializationException
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.container.container import Container
+from fabric_cf.actor.core.util.log_helper import LogHelper
 
 if TYPE_CHECKING:
     from fabric_cf.actor.core.apis.abc_actor_container import ABCActorContainer
     from fabric_cf.actor.boot.configuration import Configuration
 
+logging.TRACE = 5
+logging.addLevelName(logging.TRACE, "TRACE")
+logging.Logger.trace = lambda inst, msg, *args, **kwargs: inst.log(logging.TRACE, msg, *args, **kwargs)
+logging.trace = lambda msg, *args, **kwargs: logging.log(logging.TRACE, msg, *args, **kwargs)
+
 
 class Globals:
     config_file = Constants.CONFIGURATION_FILE
+    RPC_TIMEOUT = 0
 
     def __init__(self):
         self.config = None
@@ -71,50 +79,21 @@ class Globals:
         config, a custom path and/or level for the log file can be passed as
         optional arguments.
 
-       :param log_path: Path to custom log file
-       :param log_level: Custom log level
        :return: logging.Logger object
         """
-
-        # Get the log path
-        if self.config is None:
-            raise RuntimeError('No config information available')
         log_config = self.config.get_global_config().get_logging()
         if log_config is None:
             raise RuntimeError('No logging  config information available')
 
-        log_path = None
-        if Constants.PROPERTY_CONF_LOG_DIRECTORY in log_config and Constants.PROPERTY_CONF_LOG_FILE in log_config:
-            log_path = log_config[Constants.PROPERTY_CONF_LOG_DIRECTORY] + '/' + \
-                       log_config[Constants.PROPERTY_CONF_LOG_FILE]
+        log_dir = log_config.get(Constants.PROPERTY_CONF_LOG_DIRECTORY, ".")
+        log_file = log_config.get(Constants.PROPERTY_CONF_LOG_FILE, "actor.log")
+        log_level = log_config.get(Constants.PROPERTY_CONF_LOG_LEVEL, None)
+        log_retain = int(log_config.get(Constants.PROPERTY_CONF_LOG_RETAIN, 50))
+        log_size = int(log_config.get(Constants.PROPERTY_CONF_LOG_SIZE, 5000000))
+        logger = log_config.get(Constants.PROPERTY_CONF_LOGGER, "actor")
 
-        if log_path is None:
-            raise RuntimeError('The log file path must be specified in config or passed as an argument')
-
-        # Get the log level
-        log_level = None
-        if Constants.PROPERTY_CONF_LOG_LEVEL in log_config:
-            log_level = log_config.get(Constants.PROPERTY_CONF_LOG_LEVEL, None)
-
-        if log_level is None:
-            log_level = logging.INFO
-
-        # Set up the root logger
-        log = logging.getLogger(log_config.get(Constants.PROPERTY_CONF_LOGGER, None))
-        log.setLevel(log_level)
-        log_format = \
-            '%(asctime)s - %(name)s - {%(filename)s:%(lineno)d} - [%(threadName)s] - %(levelname)s - %(message)s'
-
-        os.makedirs(os.path.dirname(log_path), exist_ok=True)
-
-        backup_count = log_config.get(Constants.PROPERTY_CONF_LOG_RETAIN, None)
-        max_log_size = log_config.get(Constants.PROPERTY_CONF_LOG_SIZE, None)
-
-        file_handler = RotatingFileHandler(log_path, backupCount=int(backup_count), maxBytes=int(max_log_size))
-
-        logging.basicConfig(handlers=[file_handler], format=log_format)
-
-        return log
+        return LogHelper.make_logger(log_dir=log_dir, log_file=log_file, log_level=log_level, log_retain=log_retain,
+                                     log_size=log_size, logger=logger)
 
     @staticmethod
     def delete_super_block():
@@ -124,6 +103,75 @@ class Globals:
         if os.path.isfile(Constants.SUPERBLOCK_LOCATION):
             os.remove(Constants.SUPERBLOCK_LOCATION)
 
+    def create_maintenance_lock(self):
+        """
+        Create Super Block
+        """
+        self.get_logger().debug("Creating maintenance lock")
+        file = None
+        try:
+            file = open(Constants.MAINTENANCE_LOCATION, 'r')
+        except IOError:
+            file = open(Constants.MAINTENANCE_LOCATION, 'w')
+        finally:
+            if file is not None:
+                file.close()
+
+    @staticmethod
+    def delete_maintenance_lock():
+        """
+        Delete maintenance block file
+        """
+        if os.path.isfile(Constants.MAINTENANCE_LOCATION):
+            os.remove(Constants.MAINTENANCE_LOCATION)
+
+    @staticmethod
+    def is_maintenance_mode_on() -> bool:
+        if os.path.isfile(Constants.MAINTENANCE_LOCATION):
+            return True
+        return False
+
+    @staticmethod
+    def can_reload_model() -> bool:
+        if os.path.isfile(Constants.MODEL_RELOAD_LOCATION):
+            return True
+        return False
+
+    @staticmethod
+    def delete_reload_model_state_file():
+        """
+        Delete reload model state file
+        """
+        if os.path.isfile(Constants.MODEL_RELOAD_LOCATION):
+            os.remove(Constants.MODEL_RELOAD_LOCATION)
+
+    def cleanup_neo4j(self):
+        """
+        Cleanup Neo4j on clean restart
+        """
+        self.log.debug("Cleanup Neo4j database started")
+        config = self.get_config().get_neo4j_config()
+        neo4j_graph_importer = Neo4jGraphImporter(url=config["url"], user=config["user"],
+                                                  pswd=config["pass"],
+                                                  import_host_dir=config["import_host_dir"],
+                                                  import_dir=config["import_dir"])
+        neo4j_graph_importer.delete_all_graphs()
+        self.log.debug("Cleanup Neo4j database completed")
+
+    def check_and_reload_model(self, *, graph_id) -> ABCARMPropertyGraph or None:
+        """
+            Reload Neo4j on model restart
+        """
+        if not self.can_reload_model():
+            return None
+        self.cleanup_neo4j()
+        self.log.debug(f"Reload Neo4j database started {graph_id}")
+        from fabric_cf.actor.fim.fim_helper import FimHelper
+        arm_graph = FimHelper.get_arm_graph_from_file(filename=self.get_config().get_actor().get_substrate_file(),
+                                                      graph_id=graph_id)
+        self.log.debug(f"Reload Neo4j database completed {graph_id}")
+        return arm_graph
+
     def fail(self, *, e: Exception):
         """
         Fail the Actor
@@ -169,6 +217,7 @@ class Globals:
             from fabric_cf.actor.boot.configuration_loader import ConfigurationLoader
             loader = ConfigurationLoader(path=self.config_file)
             self.config = loader.read_configuration()
+            self.RPC_TIMEOUT = self.config.get_rpc_request_timeout_seconds()
         except Exception as e:
             raise RuntimeError("Unable to parse configuration file {}".format(e))
 
@@ -193,6 +242,13 @@ class Globals:
             raise InitializationException(Constants.UNINITIALIZED_STATE)
         return self.config
 
+    def get_log_config(self) -> dict:
+        """
+        Get the Log configuration
+        @return dict
+        """
+        return self.get_config().get_log_config()
+
     def get_kafka_config_admin_client(self) -> dict:
         """
         Get Kafka Config Admin Client
@@ -200,23 +256,17 @@ class Globals:
         """
         if self.config is None or self.config.get_runtime_config() is None:
             return None
-        bootstrap_server = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SERVER, None)
-        security_protocol = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SECURITY_PROTOCOL, None)
-        ssl_ca_location = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_S_SL_CA_LOCATION, None)
-        ssl_certificate_location = self.config.get_runtime_config().get(
-            Constants.PROPERTY_CONF_KAFKA_SSL_CERTIFICATE_LOCATION, None)
-        ssl_key_location = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SSL_KEY_LOCATION, None)
-        ssl_key_password = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SSL_KEY_PASSWORD, None)
-        sasl_username = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_PRODUCER_USERNAME, None)
-        sasl_password = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_PRODUCER_PASSWORD, None)
-        sasl_mechanism = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_MECHANISM, None)
 
-        conf = {Constants.BOOTSTRAP_SERVERS: bootstrap_server,
-                Constants.SECURITY_PROTOCOL: security_protocol,
-                Constants.SSL_CA_LOCATION: ssl_ca_location,
-                Constants.SSL_CERTIFICATE_LOCATION: ssl_certificate_location,
-                Constants.SSL_KEY_LOCATION: ssl_key_location,
-                Constants.SSL_KEY_PASSWORD: ssl_key_password}
+        sasl_username = self.config.get_kafka_prod_user_name()
+        sasl_password = self.config.get_kafka_prod_user_pwd()
+        sasl_mechanism = self.config.get_kafka_sasl_mechanism()
+
+        conf = {Constants.BOOTSTRAP_SERVERS: self.config.get_kafka_server(),
+                Constants.SECURITY_PROTOCOL: self.config.get_kafka_security_protocol(),
+                Constants.SSL_CA_LOCATION: self.config.get_kafka_ssl_ca_location(),
+                Constants.SSL_CERTIFICATE_LOCATION: self.config.get_kafka_ssl_cert_location(),
+                Constants.SSL_KEY_LOCATION: self.config.get_kafka_ssl_key_location(),
+                Constants.SSL_KEY_PASSWORD: self.config.get_kafka_ssl_key_password()}
 
         if sasl_username is not None and sasl_username != '' and sasl_password is not None and sasl_password != '':
             conf[Constants.SASL_USERNAME] = sasl_username
@@ -232,26 +282,19 @@ class Globals:
         """
         if self.config is None or self.config.get_runtime_config() is None:
             return None
-        bootstrap_server = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SERVER, None)
-        schema_registry = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SCHEMA_REGISTRY, None)
-        security_protocol = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SECURITY_PROTOCOL, None)
-        ssl_ca_location = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_S_SL_CA_LOCATION, None)
-        ssl_certificate_location = self.config.get_runtime_config().get(
-            Constants.PROPERTY_CONF_KAFKA_SSL_CERTIFICATE_LOCATION, None)
-        ssl_key_location = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SSL_KEY_LOCATION, None)
-        ssl_key_password = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SSL_KEY_PASSWORD, None)
 
-        sasl_username = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_PRODUCER_USERNAME, None)
-        sasl_password = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_PRODUCER_PASSWORD, None)
-        sasl_mechanism = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_MECHANISM, None)
+        sasl_username = self.config.get_kafka_prod_user_name()
+        sasl_password = self.config.get_kafka_prod_user_pwd()
+        sasl_mechanism = self.config.get_kafka_sasl_mechanism()
 
-        conf = {Constants.BOOTSTRAP_SERVERS: bootstrap_server,
-                Constants.SECURITY_PROTOCOL: security_protocol,
-                Constants.SSL_CA_LOCATION: ssl_ca_location,
-                Constants.SSL_CERTIFICATE_LOCATION: ssl_certificate_location,
-                Constants.SSL_KEY_LOCATION: ssl_key_location,
-                Constants.SSL_KEY_PASSWORD: ssl_key_password,
-                Constants.SCHEMA_REGISTRY_URL: schema_registry}
+        conf = {Constants.BOOTSTRAP_SERVERS: self.config.get_kafka_server(),
+                Constants.SECURITY_PROTOCOL: self.config.get_kafka_security_protocol(),
+                Constants.SSL_CA_LOCATION: self.config.get_kafka_ssl_ca_location(),
+                Constants.SSL_CERTIFICATE_LOCATION: self.config.get_kafka_ssl_cert_location(),
+                Constants.SSL_KEY_LOCATION: self.config.get_kafka_ssl_key_location(),
+                Constants.SSL_KEY_PASSWORD: self.config.get_kafka_ssl_key_password(),
+                Constants.SCHEMA_REGISTRY_URL: self.config.get_kafka_schema_registry(),
+                Constants.PROPERTY_CONF_KAFKA_REQUEST_TIMEOUT_MS: self.config.get_kafka_request_timeout_ms()}
 
         if sasl_username is not None and sasl_username != '' and sasl_password is not None and sasl_password != '':
             conf[Constants.SASL_USERNAME] = sasl_username
@@ -269,12 +312,12 @@ class Globals:
             return None
         conf = self.get_kafka_config_producer()
 
-        group_id = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_GROUP_ID, None)
+        group_id = self.config.get_kafka_cons_group_id()
 
         conf['auto.offset.reset'] = 'earliest'
 
-        sasl_username = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_CONSUMER_USERNAME, None)
-        sasl_password = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_SASL_CONSUMER_PASSWORD, None)
+        sasl_username = self.config.get_kafka_cons_user_name()
+        sasl_password = self.config.get_kafka_cons_user_pwd()
 
         if sasl_username is not None and sasl_username != '' and sasl_password is not None and sasl_password != '':
             conf[Constants.SASL_USERNAME] = sasl_username
@@ -282,36 +325,32 @@ class Globals:
         conf[Constants.GROUP_ID] = group_id
         return conf
 
-    def get_kafka_schemas(self):
-        """
-        Get Avro schema
-        @return key and value schema
-        """
-        key_schema_file = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_KEY_SCHEMA, None)
-        value_schema_file = self.config.get_runtime_config().get(Constants.PROPERTY_CONF_KAFKA_VALUE_SCHEMA, None)
-
-        from confluent_kafka import avro
-        file = open(key_schema_file, "r")
-        kbytes = file.read()
-        file.close()
-        key_schema = avro.loads(kbytes)
-        file = open(value_schema_file, "r")
-        vbytes = file.read()
-        file.close()
-        val_schema = avro.loads(vbytes)
-
-        return key_schema, val_schema
-
     def get_kafka_producer(self):
         """
         Create and return a kafka producer
         @return producer
         """
         conf = self.get_kafka_config_producer()
-        key_schema, val_schema = self.get_kafka_schemas()
+        key_schema_file = self.config.get_kafka_key_schema_location()
+        value_schema_file = self.config.get_kafka_value_schema_location()
 
         from fabric_mb.message_bus.producer import AvroProducerApi
-        producer = AvroProducerApi(conf=conf, key_schema=key_schema, record_schema=val_schema, logger=self.get_logger())
+        producer = AvroProducerApi(producer_conf=conf, key_schema_location=key_schema_file,
+                                   value_schema_location=value_schema_file, logger=self.get_logger())
+        return producer
+
+    def get_kafka_producer_with_poller(self, *, actor):
+        """
+        Create and return a kafka producer
+        @return producer
+        """
+        conf = self.get_kafka_config_producer()
+        key_schema_file = self.config.get_kafka_key_schema_location()
+        value_schema_file = self.config.get_kafka_value_schema_location()
+
+        from fabric_cf.actor.core.container.rpc_producer import RPCProducer
+        producer = RPCProducer(producer_conf=conf, key_schema_location=key_schema_file,
+                               value_schema_location=value_schema_file, logger=self.get_logger(), actor=actor)
         return producer
 
     def get_simple_kafka_producer(self):
