@@ -25,13 +25,14 @@
 # Author: Komal Thareja (kthare10@renci.org)
 from __future__ import annotations
 
+import logging
 import traceback
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, List
 
 import threading
 
 from fabric_mb.message_bus.consumer import AvroConsumerApi
-from fabric_mb.message_bus.messages.message import IMessageAvro
+from fabric_mb.message_bus.messages.abc_message_avro import AbcMessageAvro
 
 from fabric_cf.actor.core.common.exceptions import KafkaServiceException
 
@@ -41,10 +42,12 @@ if TYPE_CHECKING:
 
 
 class MessageService(AvroConsumerApi):
-    def __init__(self, *, kafka_service: ActorService, kafka_mgmt_service: KafkaActorService, conf: dict, key_schema,
-                 record_schema, topics, batch_size=5, logger=None):
-        super().__init__(conf=conf, key_schema=key_schema, record_schema=record_schema, topics=topics,
-                         batch_size=batch_size, logger=logger)
+    def __init__(self, *, kafka_service: ActorService, kafka_mgmt_service: KafkaActorService, consumer_conf: dict,
+                 key_schema_location, value_schema_location: str, topics: List[str], batch_size: int = 5,
+                 logger: logging.Logger = None, sync: bool = False):
+        super(MessageService, self).__init__(consumer_conf=consumer_conf, key_schema_location=key_schema_location,
+                                             value_schema_location=value_schema_location, topics=topics,
+                                             batch_size=batch_size, logger=logger, sync=sync)
         self.thread_lock = threading.Lock()
         self.thread = None
         self.kafka_service = kafka_service
@@ -56,7 +59,7 @@ class MessageService(AvroConsumerApi):
             if self.thread is not None:
                 raise KafkaServiceException("This Message Service has already been started")
 
-            self.thread = threading.Thread(target=self.consume_auto)
+            self.thread = threading.Thread(target=self.consume)
             self.thread.setName("MessageService")
             self.thread.setDaemon(True)
             self.thread.start()
@@ -75,31 +78,32 @@ class MessageService(AvroConsumerApi):
                 try:
                     temp.join()
                 except Exception as e:
-                    self.logger.error("Could not join actor thread {}".format(e))
+                    self.logger.error("Could not join Message Service thread {}".format(e))
                 finally:
                     self.thread_lock.release()
         finally:
             if self.thread_lock is not None and self.thread_lock.locked():
                 self.thread_lock.release()
 
-    def handle_message(self, message: IMessageAvro):
+    def handle_message(self, message: AbcMessageAvro):
         try:
-            if message.get_message_name() == IMessageAvro.claim_resources or \
-                    message.get_message_name() == IMessageAvro.reclaim_resources or \
-                    message.get_message_name() == IMessageAvro.get_slices_request or \
-                    message.get_message_name() == IMessageAvro.get_reservations_request or \
-                    message.get_message_name() == IMessageAvro.get_reservations_state_request or \
-                    message.get_message_name() == IMessageAvro.get_delegations or \
-                    message.get_message_name() == IMessageAvro.get_reservation_units_request or \
-                    message.get_message_name() == IMessageAvro.get_unit_request or \
-                    message.get_message_name() == IMessageAvro.get_pool_info_request or \
-                    message.get_message_name() == IMessageAvro.add_slice or \
-                    message.get_message_name() == IMessageAvro.update_slice or \
-                    message.get_message_name() == IMessageAvro.remove_slice or \
-                    message.get_message_name() == IMessageAvro.close_reservations or \
-                    message.get_message_name() == IMessageAvro.update_reservation or \
-                    message.get_message_name() == IMessageAvro.remove_reservation or \
-                    message.get_message_name() == IMessageAvro.extend_reservation:
+            if message.get_message_name() == AbcMessageAvro.claim_resources or \
+                    message.get_message_name() == AbcMessageAvro.reclaim_resources or \
+                    message.get_message_name() == AbcMessageAvro.get_slices_request or \
+                    message.get_message_name() == AbcMessageAvro.get_reservations_request or \
+                    message.get_message_name() == AbcMessageAvro.get_reservations_state_request or \
+                    message.get_message_name() == AbcMessageAvro.get_delegations or \
+                    message.get_message_name() == AbcMessageAvro.get_reservation_units_request or \
+                    message.get_message_name() == AbcMessageAvro.get_unit_request or \
+                    message.get_message_name() == AbcMessageAvro.get_broker_query_model_request or \
+                    message.get_message_name() == AbcMessageAvro.add_slice or \
+                    message.get_message_name() == AbcMessageAvro.update_slice or \
+                    message.get_message_name() == AbcMessageAvro.remove_slice or \
+                    message.get_message_name() == AbcMessageAvro.close_reservations or \
+                    message.get_message_name() == AbcMessageAvro.update_reservation or \
+                    message.get_message_name() == AbcMessageAvro.remove_reservation or \
+                    message.get_message_name() == AbcMessageAvro.extend_reservation or \
+                    message.get_message_name() == AbcMessageAvro.maintenance_request:
                 self.kafka_mgmt_service.process(message=message)
             else:
                 self.kafka_service.process(message=message)
