@@ -45,6 +45,7 @@ from fabric_cf.actor.core.kernel.failed_rpc import FailedRPC
 from fabric_cf.actor.core.kernel.kernel_wrapper import KernelWrapper
 from fabric_cf.actor.core.kernel.rpc_manager_singleton import RPCManagerSingleton
 from fabric_cf.actor.core.kernel.resource_set import ResourceSet
+from fabric_cf.actor.core.kernel.slice import SliceTypes
 from fabric_cf.actor.core.proxies.proxy import Proxy
 from fabric_cf.actor.core.time.actor_clock import ActorClock
 from fabric_cf.actor.core.time.term import Term
@@ -141,8 +142,6 @@ class ActorMixin(ABCActorMixin):
         # A queue of timers that have fired and need to be processed.
         self.timer_queue = queue.Queue()
         self.event_queue = queue.Queue()
-        self.reservation_tracker = None
-        self.subscription_id = None
         # Reservations to close once recovery is complete.
         self.closing = ReservationSet()
 
@@ -164,8 +163,6 @@ class ActorMixin(ABCActorMixin):
         del state['thread']
         del state['timer_queue']
         del state['event_queue']
-        del state['reservation_tracker']
-        del state['subscription_id']
         del state['actor_main_lock']
         del state['closing']
         del state['message_service']
@@ -185,7 +182,6 @@ class ActorMixin(ABCActorMixin):
         self.thread_lock = threading.Lock()
         self.timer_queue = queue.Queue()
         self.event_queue = queue.Queue()
-        self.subscription_id = None
         self.actor_main_lock = threading.Condition()
         self.closing = ReservationSet()
         self.message_service = None
@@ -398,21 +394,20 @@ class ActorMixin(ABCActorMixin):
         return self.stopped
 
     def query(self, *, query: dict = None, caller: AuthToken = None, actor_proxy: ABCActorProxy = None,
-              handler: ABCQueryResponseHandler = None, id_token: str = None) -> dict:
+              handler: ABCQueryResponseHandler = None) -> dict:
         """
         Query an actor
         @param query query
         @param caller caller
         @param actor_proxy actor proxy
         @param handler response handler
-        @param id_token identity token
         """
         if actor_proxy is None and handler is None:
-            return self.wrapper.query(properties=query, caller=caller, id_token=id_token)
+            return self.wrapper.query(properties=query, caller=caller)
         else:
             callback = Proxy.get_callback(actor=self, protocol=actor_proxy.get_type())
             RPCManagerSingleton.get().query(actor=self, remote_actor=actor_proxy, callback=callback, query=query,
-                                            handler=handler, id_token=id_token)
+                                            handler=handler)
             return None
 
     def recover(self):
@@ -423,13 +418,14 @@ class ActorMixin(ABCActorMixin):
         self.recovery_starting()
         self.logger.debug("Recovering inventory slices")
 
-        inventory_slices = self.plugin.get_database().get_inventory_slices()
+        inventory_slices = self.plugin.get_database().get_slices(slc_type=[SliceTypes.InventorySlice])
         self.logger.debug("Found {} inventory slices".format(len(inventory_slices)))
         self.recover_slices(slices=inventory_slices)
         self.logger.debug("Recovery of inventory slices complete")
 
         self.logger.debug("Recovering client slices")
-        client_slices = self.plugin.get_database().get_client_slices()
+        client_slices = self.plugin.get_database().get_slices(slc_type=[SliceTypes.ClientSlice,
+                                                                        SliceTypes.BrokerClientSlice])
         self.logger.debug("Found {} client slices".format(len(client_slices)))
         self.recover_slices(slices=client_slices)
         self.logger.debug("Recovery of client slices complete")
@@ -493,7 +489,7 @@ class ActorMixin(ABCActorMixin):
         delegation_names = []
 
         try:
-            delegations = self.plugin.get_database().get_delegations_by_slice_id(slice_id=slice_obj.get_slice_id())
+            delegations = self.plugin.get_database().get_delegations(slice_id=str(slice_obj.get_slice_id()))
         except Exception as e:
             self.logger.error(e)
             raise ActorException(f"Could not fetch delegations records for slice {slice_obj} from database")
@@ -576,7 +572,7 @@ class ActorMixin(ABCActorMixin):
             "Starting to recover reservations in slice {}({})".format(slice_obj.get_name(), slice_obj.get_slice_id()))
         reservations = None
         try:
-            reservations = self.plugin.get_database().get_reservations_by_slice_id(slice_id=slice_obj.get_slice_id())
+            reservations = self.plugin.get_database().get_reservations(slice_id=slice_obj.get_slice_id())
         except Exception as e:
             self.logger.error(e)
             raise ActorException(
@@ -639,7 +635,7 @@ class ActorMixin(ABCActorMixin):
         self.logger.info(
             "Starting to recover delegations in slice {}({})".format(slice_obj.get_name(), slice_obj.get_slice_id()))
         try:
-            delegations = self.plugin.get_database().get_delegations_by_slice_id(slice_id=slice_obj.get_slice_id())
+            delegations = self.plugin.get_database().get_delegations(slice_id=str(slice_obj.get_slice_id()))
         except Exception as e:
             self.logger.error(e)
             raise ActorException(
@@ -998,10 +994,11 @@ class ActorMixin(ABCActorMixin):
             if len(events) > 0:
                 self.logger.debug(f"Processing {len(events)} events")
                 for event in events:
-                    #self.logger.debug("Processing event of type {}".format(type(e)))
-                    #self.logger.debug("Processing event {}".format(e))
+                    #self.logger.debug("Processing event of type {}".format(type(event)))
+                    #self.logger.debug("Processing event {}".format(event))
                     try:
                         event.process()
+                        #self.logger.debug("Processing event {} done".format(event))
                     except Exception as e:
                         self.logger.error(f"Error while processing event {type(event)}, {e}")
                         self.logger.error(traceback.format_exc())
