@@ -34,8 +34,8 @@ from fabric_cf.actor.core.common.exceptions import BrokerException, ExceptionErr
 from fabric_cf.actor.core.util.id import ID
 from fabric_cf.actor.core.apis.abc_authority_policy import ABCAuthorityPolicy
 from fabric_cf.actor.core.apis.abc_broker_policy_mixin import ABCBrokerPolicyMixin
-from fabric_cf.actor.core.apis.abc_reservation_mixin import ReservationCategory
-from fabric_cf.actor.core.apis.abc_kernel_broker_reservation_mixin import ABCKernelBrokerReservationMixin
+from fabric_cf.actor.core.apis.abc_reservation_mixin import ReservationCategory, ABCReservationMixin
+from fabric_cf.actor.core.apis.abc_broker_reservation import ABCBrokerReservation
 from fabric_cf.actor.core.kernel.rpc_manager_singleton import RPCManagerSingleton
 from fabric_cf.actor.core.kernel.rpc_request_type import RPCRequestType
 from fabric_cf.actor.core.kernel.request_types import RequestTypes
@@ -50,12 +50,11 @@ if TYPE_CHECKING:
     from fabric_cf.actor.core.apis.abc_policy import ABCPolicy
     from fabric_cf.actor.core.apis.abc_slice import ABCSlice
     from fabric_cf.actor.core.kernel.failed_rpc import FailedRPC
-    from fabric_cf.actor.core.apis.abc_kernel_slice import ABCKernelSlice
     from fabric_cf.actor.core.kernel.resource_set import ResourceSet
     from fabric_cf.actor.core.time.term import Term
 
 
-class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
+class BrokerReservation(ReservationServer, ABCBrokerReservation):
     """
     A note on exported "will call" reservations. An export() operation may be
     locally initiated on an agent. It binds and forms a ticket in the same way as
@@ -69,7 +68,7 @@ class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
     """
     updated_absorbed = "update absorbed"
 
-    def __init__(self, *, rid: ID, resources: ResourceSet, term: Term, slice_obj: ABCKernelSlice):
+    def __init__(self, *, rid: ID, resources: ResourceSet, term: Term, slice_obj: ABCSlice):
         super().__init__(rid=rid, resources=resources, term=term, slice_object=slice_obj)
         # Delegation backing the ticket granted to this reservation. For now only
         # one source delegation can be used to issue a ticket to satisfy a client
@@ -203,20 +202,6 @@ class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
             raise BrokerException(error_code=ExceptionErrorCode.UNEXPECTED_STATE,
                                   msg=f"state={self.state}")
 
-    def handle_failed_rpc(self, *, failed: FailedRPC):
-        # make sure that the failed RPC came from the callback identity
-        remote_auth = failed.get_remote_auth()
-        if failed.get_request_type() == RPCRequestType.UpdateTicket:
-            if self.callback is None or self.callback.get_identity() != remote_auth:
-                raise BrokerException(msg=f"Unauthorized Failed reservation RPC: "
-                                          f"expected={self.callback.get_identity()}, but was: {remote_auth}")
-        else:
-            raise BrokerException(error_code=ExceptionErrorCode.NOT_SUPPORTED,
-                                  msg=f"Unexpected FailedRPC for BrokerReservation. "
-                                      f"RequestType={failed.get_request_type()}")
-
-        super().handle_failed_rpc(failed=failed)
-
     def prepare(self, *, callback: ABCCallbackProxy, logger):
         self.set_logger(logger=logger)
         self.callback = callback
@@ -442,7 +427,7 @@ class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
                     self.transition(prefix="ticket request", state=ReservationStates.Nascent,
                                     pending=ReservationPendingStates.Ticketing)
                 except Exception as e:
-                    self.logger.error("mapAndUpdate bindTicket failed for ticketRequest:", exception=e)
+                    self.logger.error(f"mapAndUpdate bindTicket failed for ticketRequest: {e}")
                     self.fail_notify(message=str(e))
                     return success
 
@@ -456,7 +441,9 @@ class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
                         self.transition(prefix="ticketed", state=ReservationStates.Ticketed,
                                         pending=ReservationPendingStates.Priming)
                     except Exception as e:
-                        self.logger.error("mapAndUpdate ticket failed for ticketRequest", exception=e)
+                        self.logger.error("mapAndUpdate ticket failed for ticketRequest")
+                        self.logger.error(e)
+                        self.logger.error(traceback.format_exc())
                         self.fail_notify(message=str(e))
         elif self.state == ReservationStates.Ticketed:
             if not ticketed:
@@ -481,7 +468,7 @@ class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
                     else:
                         granted = True
                 except Exception as e:
-                    self.logger.error("mapAndUpdate extendTicket failed for ticketRequest:", exception=e)
+                    self.logger.error(f"mapAndUpdate extendTicket failed for ExtendTicket: {e}")
                     self.fail_notify(message=str(e))
                     return success
 
@@ -496,7 +483,7 @@ class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
                         self.term = self.approved_term
                         self.resources.update(reservation=self, resource_set=self.approved_resources)
                     except Exception as e:
-                        self.logger.error("mapAndUpdate ticket failed for ticketRequest", exception=e)
+                        self.logger.error(f"mapAndUpdate extend ticket failed for ExtendTicket: {e}")
                         self.fail_notify(message=str(e))
         else:
             self.logger.error("broker mapAndUpdate: unexpected state")
@@ -536,6 +523,17 @@ class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
     def set_authority(self, *, authority: ABCAuthorityProxy):
         self.authority = authority
 
+    def update_lease(self, *, incoming: ABCReservationMixin, update_data):
+        self.logger.info(f"Received Update Lease: {incoming} at Broker")
+        # TODO add any processing if needed
+        self.logger.info(f"Do Nothing!")
+
+    def handle_failed_rpc(self, *, failed: FailedRPC):
+        if failed.get_request_type() == RPCRequestType.UpdateTicket and \
+                self.last_pending_state == ReservationPendingStates.ExtendingTicket:
+            return
+        super().handle_failed_rpc(failed=failed)
+
 
 class BrokerReservationFactory:
     @staticmethod
