@@ -37,14 +37,11 @@ from fabric_cf.actor.core.apis.abc_controller_callback_proxy import ABCControlle
 from fabric_cf.actor.core.apis.abc_controller_reservation import ABCControllerReservation
 from fabric_cf.actor.core.apis.abc_delegation import ABCDelegation
 from fabric_cf.actor.core.apis.abc_policy import ABCPolicy
-from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
 from fabric_cf.actor.core.apis.abc_slice import ABCSlice
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.common.exceptions import SliceNotFoundException
 from fabric_cf.actor.core.kernel.failed_rpc import FailedRPC
-from fabric_cf.actor.core.apis.abc_kernel_client_reservation_mixin import ABCKernelClientReservationMixin
-from fabric_cf.actor.core.apis.abc_kernel_reservation import ABCKernelReservation
-from fabric_cf.actor.core.apis.abc_kernel_slice import ABCKernelSlice
+from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
 from fabric_cf.actor.core.kernel.kernel import Kernel
 from fabric_cf.actor.core.common.exceptions import KernelException
 from fabric_cf.actor.core.kernel.request_types import RequestTypes
@@ -57,7 +54,7 @@ from fabric_cf.actor.core.util.id import ID
 from fabric_cf.actor.core.util.update_data import UpdateData
 from fabric_cf.actor.security.access_checker import AccessChecker
 from fabric_cf.actor.security.auth_token import AuthToken
-from fabric_cf.actor.security.pdp_auth import ActionId, ResourceType
+from fabric_cf.actor.security.pdp_auth import ActionId
 
 
 class KernelWrapper:
@@ -81,8 +78,8 @@ class KernelWrapper:
         """
         self.kernel.await_nothing_pending()
 
-    def claim_delegation_request(self, *, delegation: ABCDelegation, caller: AuthToken, callback: ABCClientCallbackProxy,
-                                 id_token: str = None):
+    def claim_delegation_request(self, *, delegation: ABCDelegation, caller: AuthToken,
+                                 callback: ABCClientCallbackProxy):
         """
         Processes a request to claim a pre-advertised delegation
 
@@ -91,24 +88,19 @@ class KernelWrapper:
         @param delegation delegation describing the claim request
         @param caller caller identity
         @param callback callback proxy
-        @param id_token identity token
         @raises Exception in case of error
         """
         if delegation is None or caller is None or callback is None:
             raise KernelException(Constants.INVALID_ARGUMENT)
 
-        if id_token is not None:
-            AccessChecker.check_access(action_id=ActionId.claim, resource_type=ResourceType.delegation,
-                                       token=id_token, logger=self.logger, actor_type=self.actor.get_type())
-
         # Note: for claim we do not need the slice object, so we use
-        # validate(ReservationID) instead of validate(Reservation).
+        # validate_delegation(delegation_id) instead of validate_delegation(delegation).
         exported = self.kernel.validate_delegation(did=delegation.get_delegation_id())
         exported.prepare(callback=callback, logger=self.logger)
         self.kernel.claim_delegation(delegation=exported)
 
-    def reclaim_delegation_request(self, *, delegation: ABCDelegation, caller: AuthToken, callback: ABCClientCallbackProxy,
-                                   id_token: str = None):
+    def reclaim_delegation_request(self, *, delegation: ABCDelegation, caller: AuthToken,
+                                   callback: ABCClientCallbackProxy):
         """
         Processes a request to re-claim a pre-claimed delegation
 
@@ -117,21 +109,16 @@ class KernelWrapper:
         @param delegation delegation describing the reclaim request
         @param caller caller identity
         @param callback callback proxy
-        @param id_token identity token
         @raises Exception in case of error
         """
         if delegation is None or caller is None or callback is None:
             raise KernelException(Constants.INVALID_ARGUMENT)
 
-        if id_token is not None:
-            AccessChecker.check_access(action_id=ActionId.claim, resource_type=ResourceType.delegation,
-                                       token=id_token, logger=self.logger, actor_type=self.actor.get_type())
-
         # Note: for claim we do not need the slice object, so we use
         # validate(ReservationID) instead of validate(Reservation).
         exported = self.kernel.validate_delegation(did=delegation.get_delegation_id())
         exported.prepare(callback=callback, logger=self.logger)
-        self.kernel.reclaim_delegation(delegation=exported, id_token=id_token)
+        self.kernel.reclaim_delegation(delegation=exported)
 
     def fail(self, *, rid: ID, message: str):
         """
@@ -257,7 +244,7 @@ class KernelWrapper:
         self.kernel.extend_lease(reservation=reservation)
 
     def extend_lease_request(self, *, reservation: ABCAuthorityReservation, caller: AuthToken,
-                             compare_sequence_numbers: bool):
+                             compare_sequence_numbers: bool, callback: ABCControllerCallbackProxy = None,):
         """
         Processes an incoming request for a lease extension.
         Role: Authority
@@ -266,32 +253,41 @@ class KernelWrapper:
         @param compare_sequence_numbers if true, the incoming sequence number will
                    be compared to the local sequence number to detect fresh
                    requests, if false, no comparison will be performed.
+        @param callback callback to be used to send failure response when the request fails.
         @throws Exception in case of error
         """
         if reservation is None or caller is None:
             raise KernelException(Constants.INVALID_ARGUMENT)
+        try:
+            AccessChecker.check_access(action_id=ActionId.renew, token=caller.get_token(),
+                                       resource=reservation.get_requested_resources().get_sliver(),
+                                       lease_end_time=reservation.get_requested_term().get_end_time(),
+                                       logger=self.logger)
+            if compare_sequence_numbers:
+                reservation.validate_incoming()
+                target = self.kernel.validate(rid=reservation.get_reservation_id())
 
-        if compare_sequence_numbers:
-            reservation.validate_incoming()
-            target = self.kernel.validate(rid=reservation.get_reservation_id())
+                sequence_compare = self.kernel.compare_and_update(incoming=reservation, current=target)
+                if sequence_compare == SequenceComparisonCodes.SequenceGreater:
+                    target.prepare_extend_lease()
+                    self.kernel.extend_lease(reservation=target)
 
-            sequence_compare = self.kernel.compare_and_update(incoming=reservation, current=target)
-            if sequence_compare == SequenceComparisonCodes.SequenceGreater:
-                target.prepare_extend_lease()
+                elif sequence_compare == SequenceComparisonCodes.SequenceSmaller:
+                    self.logger.warning("extendLeaseRequest with a smaller sequence number")
+
+                elif sequence_compare == SequenceComparisonCodes.SequenceEqual:
+                    self.logger.warning("duplicate extendLease request")
+                    self.kernel.handle_duplicate_request(current=target, operation=RequestTypes.RequestExtendLease)
+            else:
+                target = self.kernel.validate(rid=reservation.get_reservation_id())
                 self.kernel.extend_lease(reservation=target)
-
-            elif sequence_compare == SequenceComparisonCodes.SequenceSmaller:
-                self.logger.warning("extendLeaseRequest with a smaller sequence number")
-
-            elif sequence_compare == SequenceComparisonCodes.SequenceEqual:
-                self.logger.warning("duplicate extendLease request")
-                self.kernel.handle_duplicate_request(current=target, operation=RequestTypes.RequestExtendLease)
-        else:
-            target = self.kernel.validate(rid=reservation.get_reservation_id())
-            self.kernel.extend_lease(reservation=target)
+        except Exception as e:
+            self.logger.error(f"Exception occurred {e}")
+            self.logger.error(traceback.format_exc())
+            self.fail_notify(reservation=reservation, caller=caller, callback=callback, reason=str(e))
 
     def modify_lease_request(self, *, reservation: ABCAuthorityReservation, caller: AuthToken,
-                             compare_sequence_numbers: bool):
+                             compare_sequence_numbers: bool, callback: ABCControllerCallbackProxy = None,):
         """
         Processes an incoming request for a lease modification.
         Role: Authority
@@ -300,30 +296,40 @@ class KernelWrapper:
         @param compare_sequence_numbers if true, the incoming sequence number will
                    be compared to the local sequence number to detect fresh
                    requests, if false, no comparison will be performed.
+        @param callback callback to be used to send failure response when the request fails.
         @throws Exception in case of error
         """
         if reservation is None or caller is None:
             raise KernelException(Constants.INVALID_ARGUMENT)
 
-        if compare_sequence_numbers:
-            reservation.validate_incoming()
-            target = self.kernel.validate(rid=reservation.get_reservation_id())
+        try:
+            AccessChecker.check_access(action_id=ActionId.modify, token=caller.get_token(),
+                                       resource=reservation.get_requested_resources().get_sliver(),
+                                       lease_end_time=reservation.get_requested_term().get_end_time(),
+                                       logger=self.logger)
+            if compare_sequence_numbers:
+                reservation.validate_incoming()
+                target = self.kernel.validate(rid=reservation.get_reservation_id())
 
-            sequence_compare = self.kernel.compare_and_update(incoming=reservation, current=target)
+                sequence_compare = self.kernel.compare_and_update(incoming=reservation, current=target)
 
-            if sequence_compare == SequenceComparisonCodes.SequenceGreater:
-                target.prepare_modify_lease()
-                self.kernel.modify_lease(reservation=reservation)
+                if sequence_compare == SequenceComparisonCodes.SequenceGreater:
+                    target.prepare_modify_lease()
+                    self.kernel.modify_lease(reservation=target)
 
-            elif sequence_compare == SequenceComparisonCodes.SequenceSmaller:
-                self.logger.warning("modifyLeaseRequest with a smaller sequence number")
+                elif sequence_compare == SequenceComparisonCodes.SequenceSmaller:
+                    self.logger.warning("modifyLeaseRequest with a smaller sequence number")
 
-            elif sequence_compare == SequenceComparisonCodes.SequenceEqual:
-                self.logger.warning("duplicate extendLease request")
-                self.kernel.handle_duplicate_request(current=target, operation=RequestTypes.RequestModifyLease)
-        else:
-            target = self.kernel.validate(rid=reservation.get_reservation_id())
-            self.kernel.modify_lease(reservation=target)
+                elif sequence_compare == SequenceComparisonCodes.SequenceEqual:
+                    self.logger.warning("duplicate extendLease request")
+                    self.kernel.handle_duplicate_request(current=target, operation=RequestTypes.RequestModifyLease)
+            else:
+                target = self.kernel.validate(rid=reservation.get_reservation_id())
+                self.kernel.modify_lease(reservation=target)
+        except Exception as e:
+            self.logger.error(f"Exception occurred {e}")
+            self.logger.error(traceback.format_exc())
+            self.fail_notify(reservation=reservation, caller=caller, callback=callback, reason=str(e))
 
     def extend_reservation(self, *, rid: ID, resources: ResourceSet, term: Term) -> int:
         """
@@ -358,7 +364,7 @@ class KernelWrapper:
         self.kernel.extend_ticket(reservation=target)
 
     def extend_ticket_request(self, *, reservation: ABCBrokerReservation, caller: AuthToken,
-                              compare_sequence_numbers: bool):
+                              compare_sequence_numbers: bool, callback: ABCClientCallbackProxy = None):
         """
         Processes an incoming request for a ticket extension.
         Role: Broker
@@ -367,33 +373,45 @@ class KernelWrapper:
         @param compare_sequence_numbers if true, the incoming sequence number will
                    be compared to the local sequence number to detect fresh
                    requests, if false, no comparison will be performed.
+        @param callback callback to be used to send the response back if the request failed
         @throws Exception in case of error
         """
         self.logger.debug("extend_ticket_request")
         if reservation is None or caller is None:
             raise KernelException(Constants.INVALID_ARGUMENT)
-        if compare_sequence_numbers:
-            target = self.kernel.validate(rid=reservation.get_reservation_id())
 
-            sequence_compare = self.kernel.compare_and_update(incoming=reservation, current=target)
+        try:
+            AccessChecker.check_access(action_id=ActionId.renew, token=caller.get_token(),
+                                       resource=reservation.get_requested_resources().get_sliver(),
+                                       lease_end_time=reservation.get_requested_term().get_end_time(),
+                                       logger=self.logger)
 
-            if sequence_compare == SequenceComparisonCodes.SequenceGreater:
-                self.logger.debug("extend_ticket SequenceGreater")
-                self.kernel.extend_ticket(reservation=target)
+            if compare_sequence_numbers:
+                target = self.kernel.validate(rid=reservation.get_reservation_id())
 
-            elif sequence_compare == SequenceComparisonCodes.SequenceInProgress:
-                self.logger.warning("New request for a reservation with a pending action")
+                sequence_compare = self.kernel.compare_and_update(incoming=reservation, current=target)
 
-            elif sequence_compare == SequenceComparisonCodes.SequenceSmaller:
-                self.logger.warning("Incoming extendTicket request has smaller sequence number")
+                if sequence_compare == SequenceComparisonCodes.SequenceGreater:
+                    self.logger.debug("extend_ticket SequenceGreater")
+                    self.kernel.extend_ticket(reservation=target)
 
-            elif sequence_compare == SequenceComparisonCodes.SequenceEqual:
-                self.logger.warning("Duplicate extendTicket request")
-                self.kernel.handle_duplicate_request(current=target, operation=RequestTypes.RequestExtendTicket)
-        else:
-            target = self.kernel.validate(rid=reservation.get_reservation_id())
-            self.logger.debug("extend_ticket No sequence number comparison")
-            self.extend_ticket(reservation=target)
+                elif sequence_compare == SequenceComparisonCodes.SequenceInProgress:
+                    self.logger.warning("New request for a reservation with a pending action")
+
+                elif sequence_compare == SequenceComparisonCodes.SequenceSmaller:
+                    self.logger.warning("Incoming extendTicket request has smaller sequence number")
+
+                elif sequence_compare == SequenceComparisonCodes.SequenceEqual:
+                    self.logger.warning("Duplicate extendTicket request")
+                    self.kernel.handle_duplicate_request(current=target, operation=RequestTypes.RequestExtendTicket)
+            else:
+                target = self.kernel.validate(rid=reservation.get_reservation_id())
+                self.logger.debug("extend_ticket No sequence number comparison")
+                self.extend_ticket(reservation=target)
+        except Exception as e:
+            self.logger.error(f"Exception occurred {e}")
+            self.logger.error(traceback.format_exc())
+            self.fail_notify(reservation=reservation, caller=caller, callback=callback, reason=str(e))
 
     def modify_lease(self, *, reservation: ABCControllerReservation):
         """
@@ -501,13 +519,12 @@ class KernelWrapper:
         """
         return self.kernel.get_slices()
 
-    def handle_delegate(self, *, delegation: ABCDelegation, identity: AuthToken, id_token: str = None):
+    def handle_delegate(self, *, delegation: ABCDelegation, identity: AuthToken):
         """
         Handles a delegation. Called from both AM and Broker.
 
         @param delegation the delegation
         @param identity caller identity
-        @param id_token id token
 
         @throws Exception in case of error
         """
@@ -534,11 +551,11 @@ class KernelWrapper:
 
         if temp is None:
             self.kernel.register_delegation(delegation=delegation)
-            self.kernel.delegate(delegation=delegation, id_token=id_token)
+            self.kernel.delegate(delegation=delegation)
         else:
             self.kernel.amend_delegate(delegation=temp)
 
-    def handle_reserve(self, *, reservation: ABCKernelReservation, identity: AuthToken, create_new_slice: bool):
+    def handle_reserve(self, *, reservation: ABCReservationMixin, identity: AuthToken, create_new_slice: bool):
         """
         Handles a reserve, i.e., obtain a new ticket or lease. Called from both
         client and server side code. If the slice does not exist it will create
@@ -580,7 +597,7 @@ class KernelWrapper:
         else:
             self.kernel.amend_reserve(reservation=temp)
 
-    def handle_update_reservation(self, *, reservation: ABCKernelReservation, auth: AuthToken):
+    def handle_update_reservation(self, *, reservation: ABCReservationMixin, auth: AuthToken):
         """
         Amend a reservation request or initiation, i.e., to issue a new bid on a
         previously filed request.
@@ -590,16 +607,13 @@ class KernelWrapper:
         """
         self.kernel.amend_reserve(reservation=reservation)
 
-    def query(self, *, properties: dict, caller: AuthToken, id_token: str):
+    def query(self, *, properties: dict, caller: AuthToken):
         """
         Processes an incoming query request.
         @param properties query
         @param caller caller identity
-        @param id_token id_token
         @return query response
         """
-        AccessChecker.check_access(action_id=ActionId.query, resource_type=ResourceType.resources,
-                                   token=id_token, logger=self.logger, actor_type=self.actor.get_type())
 
         return self.kernel.query(properties=properties)
 
@@ -645,6 +659,9 @@ class KernelWrapper:
             raise KernelException(Constants.INVALID_ARGUMENT)
 
         try:
+            AccessChecker.check_access(action_id=ActionId.redeem, token=caller.get_token(),
+                                       resource=reservation.get_requested_resources().get_sliver(),
+                                       logger=self.logger)
             if compare_sequence_numbers:
                 reservation.validate_incoming()
                 reservation.get_slice().set_client()
@@ -658,15 +675,15 @@ class KernelWrapper:
                         self.kernel.handle_duplicate_request(current=target, operation=RequestTypes.RequestRedeem)
 
                 reservation.prepare(callback=callback, logger=self.logger)
-                self.handle_reserve(reservation=reservation, identity=callback, create_new_slice=True)
+                self.handle_reserve(reservation=reservation, identity=caller, create_new_slice=True)
             else:
-                reservation.set_logger(self.logger)
+                reservation.set_logger(logger=self.logger)
                 self.handle_reserve(reservation=reservation, identity=reservation.get_client_auth_token(),
                                     create_new_slice=True)
         except Exception as e:
             self.logger.error(traceback.format_exc())
             self.logger.error("Exception occurred in processing redeem request {}".format(e))
-            reservation.fail_notify(message=str(e))
+            self.fail_notify(reservation=reservation, caller=caller, callback=callback, reason=str(e))
 
     def register_reservation(self, *, reservation: ABCReservationMixin):
         """
@@ -685,11 +702,33 @@ class KernelWrapper:
                     reservation will be unregistered from the kernel data
                     structures.
         """
-        if reservation is None or not isinstance(reservation, ABCKernelReservation):
+        if reservation is None or not isinstance(reservation, ABCReservationMixin):
             raise KernelException(Constants.INVALID_ARGUMENT)
 
         self.kernel.register_reservation(reservation=reservation)
 
+    def register_delegation(self, *, delegation: ABCDelegation):
+        """
+        Registers the given delegation with the kernel. Adds a database record
+        for the delegation. The containing slice should have been previously
+        registered with the kernel and no database record should exist. When
+        registering a delegation with an existing database record use
+        #re_register_delegation(ABCDelegation)}. Only delegations
+        that are not closed or failed can be registered. Closed or failed
+        delegations will be ignored.
+        @param delegation the delegation to register
+        @throws IllegalArgumentException when the passed in argument is illegal
+        @throws Exception if the delegation has already been registered with the
+                    kernel.
+        @throws RuntimeException when a database error occurs. In this case the
+                    delegation will be unregistered from the kernel data
+                    structures.
+        """
+        if delegation is None or not isinstance(delegation, ABCDelegation):
+            raise KernelException(Constants.INVALID_ARGUMENT)
+
+        self.kernel.register_delegation(delegation=delegation)
+
     def register_slice(self, *, slice_object: ABCSlice):
         """
         Registers the slice with the kernel: adds the slice object to the kernel
@@ -699,7 +738,7 @@ class KernelWrapper:
                     occurs. If a database error occurs, the slice will be
                     unregistered.
         """
-        if slice_object is None or slice_object.get_slice_id() is None or not isinstance(slice_object, ABCKernelSlice):
+        if slice_object is None or slice_object.get_slice_id() is None or not isinstance(slice_object, ABCSlice):
             raise KernelException("Invalid argument {}".format(slice_object))
 
         slice_object.set_owner(owner=self.actor.get_identity())
@@ -752,7 +791,7 @@ class KernelWrapper:
                     kernel data structures.
         @throws RuntimeException if a database error occurs
         """
-        if reservation is None or not isinstance(reservation, ABCKernelReservation):
+        if reservation is None or not isinstance(reservation, ABCReservationMixin):
             raise KernelException(Constants.INVALID_ARGUMENT)
 
         self.kernel.re_register_reservation(reservation=reservation)
@@ -782,7 +821,7 @@ class KernelWrapper:
                     occurs. If a database error occurs, the slice will be
                     unregistered.
         """
-        if slice_object is None or slice_object.get_slice_id() is None or not isinstance(slice_object, ABCKernelSlice):
+        if slice_object is None or slice_object.get_slice_id() is None or not isinstance(slice_object, ABCSlice):
             raise KernelException(Constants.INVALID_ARGUMENT)
 
         self.kernel.re_register_slice(slice_object=slice_object)
@@ -799,14 +838,13 @@ class KernelWrapper:
             self.logger.error("Tick error: {}".format(e))
             self.logger.error(traceback.format_exc())
 
-    def delegate(self, *, delegation: ABCDelegation, destination: ABCActorIdentity, id_token: str = None):
+    def delegate(self, *, delegation: ABCDelegation, destination: ABCActorIdentity):
         """
         Initiates a delegate request. If the exported flag is set, this is a claim
         on a pre-reserved "will call" ticket.
         Role: Broker or Controller.
         @param delegation delegation parameters for ticket request
         @param destination identity of the actor the request must be sent to
-        @param id_token id token
         @throws Exception in case of error
         """
         if delegation is None or destination is None:
@@ -819,7 +857,7 @@ class KernelWrapper:
 
         delegation.prepare(callback=callback, logger=self.logger)
         delegation.validate_outgoing()
-        self.handle_delegate(delegation=delegation, identity=destination.get_identity(), id_token=id_token)
+        self.handle_delegate(delegation=delegation, identity=destination.get_identity())
 
     def ticket(self, *, reservation: ABCClientReservation, destination: ABCActorIdentity):
         """
@@ -830,7 +868,7 @@ class KernelWrapper:
         @param destination identity of the actor the request must be sent to
         @throws Exception in case of error
         """
-        if reservation is None or destination is None or not isinstance(reservation, ABCKernelClientReservationMixin):
+        if reservation is None or destination is None or not isinstance(reservation, ABCClientReservation):
             raise KernelException(Constants.INVALID_ARGUMENT)
 
         protocol = reservation.get_broker().get_type()
@@ -859,6 +897,10 @@ class KernelWrapper:
             raise KernelException(Constants.INVALID_ARGUMENT)
 
         try:
+            AccessChecker.check_access(action_id=ActionId.ticket, token=caller.get_token(),
+                                       resource=reservation.get_requested_resources().get_sliver(),
+                                       logger=self.logger)
+
             if compare_seq_numbers:
                 reservation.validate_incoming()
                 # Mark the slice as client slice.
@@ -892,11 +934,11 @@ class KernelWrapper:
                     else:
                         # This is a new reservation. No need to check sequence numbers
                         reservation.prepare(callback=callback, logger=self.logger)
-                        self.handle_reserve(reservation=reservation, identity=callback, create_new_slice=True)
+                        self.handle_reserve(reservation=reservation, identity=caller, create_new_slice=True)
                 else:
                     # New reservation for a new slice.
                     reservation.prepare(callback=callback, logger=self.logger)
-                    self.handle_reserve(reservation=reservation, identity=callback, create_new_slice=True)
+                    self.handle_reserve(reservation=reservation, identity=caller, create_new_slice=True)
             else:
                 # This is most likely a reservation being recovered. Do not compare sequence numbers,
                 # just trigger reserve.
@@ -906,7 +948,7 @@ class KernelWrapper:
         except Exception as e:
             self.logger.error(f"Exception occurred {e}")
             self.logger.error(traceback.format_exc())
-            reservation.fail_notify(message=str(e))
+            self.fail_notify(reservation=reservation, caller=caller, callback=callback, reason=str(e))
 
     def unregister_reservation(self, *, rid: ID):
         """
@@ -992,3 +1034,19 @@ class KernelWrapper:
             self.logger.warning("Could not find reservation #{} while processing a failed RPC.".format(rid))
             return
         self.kernel.handle_failed_rpc(reservation=target, rpc=rpc)
+
+    def fail_notify(self, *, reservation: ABCReservationMixin, reason: str, caller: AuthToken,
+                    callback: ABCControllerCallbackProxy):
+        """
+        Handles a fail notification from an authority or broker.
+        Broker:
+            - ExtendTicket or Ticket
+        Authority:
+            - ExtendLease or ModifyLease or Redeem
+        """
+        try:
+            reservation.get_slice().set_owner(owner=caller)
+            reservation.prepare(callback=callback, logger=self.logger)
+            reservation.fail_notify(message=reason)
+        except Exception as e:
+            self.logger.exception(f"Failed to notify reservation #{reservation.get_reservation_id()} of failure.")
\ No newline at end of file
