@@ -34,11 +34,11 @@ from datetime import datetime
 from fim.slivers.attached_components import ComponentType
 from fim.slivers.base_sliver import BaseSliver
 from fim.slivers.capacities_labels import Labels
-from fim.slivers.network_node import NodeSliver
+from fim.slivers.network_node import NodeSliver, NodeType
 from fim.slivers.network_service import ServiceType, NetworkServiceSliver
 
 from fabric_cf.actor.core.apis.abc_authority_policy import ABCAuthorityPolicy
-from fabric_cf.actor.core.apis.abc_kernel_controller_reservation_mixin import ABCKernelControllerReservationMixin
+from fabric_cf.actor.core.apis.abc_controller_reservation import ABCControllerReservation
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.common.exceptions import ReservationException
 from fabric_cf.actor.core.kernel.failed_rpc import FailedRPC
@@ -62,14 +62,14 @@ if TYPE_CHECKING:
     from fabric_cf.actor.core.apis.abc_client_callback_proxy import ABCClientCallbackProxy
     from fabric_cf.actor.core.apis.abc_client_policy import ABCClientPolicy
     from fabric_cf.actor.core.apis.abc_policy import ABCPolicy
-    from fabric_cf.actor.core.apis.abc_kernel_slice import ABCKernelSlice
+    from fabric_cf.actor.core.apis.abc_slice import ABCSlice
     from fabric_cf.actor.core.kernel.resource_set import ResourceSet
     from fabric_cf.actor.core.time.term import Term
     from fabric_cf.actor.core.util.resource_count import ResourceCount
     from fabric_cf.actor.core.util.resource_type import ResourceType
 
 
-class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
+class ReservationClient(Reservation, ABCControllerReservation):
     """
     Reservation state machine for a client-side reservation. Role: orchestrator,
     or an agent requesting tickets from an upstream agent. This class
@@ -98,7 +98,7 @@ class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
     CLOSE_COMPLETE = "close complete"
 
     def __init__(self, *, rid: ID, resources: ResourceSet = None, term: Term = None,
-                 slice_object: ABCKernelSlice = None, broker: ABCBrokerProxy = None):
+                 slice_object: ABCSlice = None, broker: ABCBrokerProxy = None):
         super().__init__(rid=rid, resources=resources, term=term, slice_object=slice_object)
         self.service_pending = JoinState.None_
         # Proxy to the broker that serves tickets for this reservation.
@@ -409,6 +409,7 @@ class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
         @return true if approved; false otherwise
         """
         approved = True
+
         for pred_state in self.redeem_predecessors.values():
             if pred_state.get_reservation() is None or \
                     pred_state.get_reservation().is_failed() or \
@@ -416,6 +417,7 @@ class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
                 self.logger.error("redeem predecessor reservation is in a terminal state or reservation is null."
                                   " ignoring it: {}".format(pred_state.get_reservation()))
                 continue
+
             if not pred_state.get_reservation().is_active_joined():
                 approved = False
                 break
@@ -450,7 +452,14 @@ class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
 
         for ifs in self.resources.sliver.interface_info.interfaces.values():
             component_name, rid = ifs.get_node_map()
+
+            if component_name == str(NodeType.Facility):
+                continue
+
             pred_state = self.redeem_predecessors.get(ID(uid=rid))
+            if not pred_state:
+                self.logger.error(f"Redeem predecessors not found {rid} for {self.get_reservation_id()}")
+                continue
             parent_res = pred_state.get_reservation()
             if parent_res is not None and \
                     ReservationStates(parent_res.get_state()) == ReservationStates.Ticketed:
@@ -506,8 +515,8 @@ class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
         return approved
 
     def can_ticket(self) -> bool:
-        supported_ns = [ServiceType.L2STS.name, ServiceType.L2Bridge.name, ServiceType.L2PTP.name,
-                        ServiceType.FABNetv4.name, ServiceType.FABNetv6.name]
+        supported_ns = [str(ServiceType.L2STS), str(ServiceType.L2Bridge), str(ServiceType.L2PTP),
+                        str(ServiceType.FABNetv4), str(ServiceType.FABNetv6), str(ServiceType.PortMirror)]
 
         ret_val = False
         if self.get_type() is not None:
@@ -574,7 +583,7 @@ class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
 
     def close(self):
         if self.state == ReservationStates.Nascent or self.state == ReservationStates.Failed:
-            self.logger.debug("Reservation in Nascent or failed state, transition to close")
+            self.logger.debug(f"Reservation in state: {self.state}, transition to {ReservationStates.Closed}")
             self.transition(prefix="close", state=ReservationStates.Closed, pending=self.pending_state)
             if self.broker is not None:
                 self.logger.debug("Triggering relinquish")
@@ -1652,8 +1661,14 @@ class ReservationClient(Reservation, ABCKernelControllerReservationMixin):
         """
         self.logger.debug(f"Updating ASM for  Reservation# {self.rid} State# {self.get_reservation_state()} "
                           f"Slice Graph# {self.slice.get_graph_id()}")
+        error_message = self.get_error_message()
+        if error_message is None:
+            error_message = self.get_last_ticket_update()
+        if error_message is None:
+            error_message = self.get_last_lease_update()
         self.slice.update_slice_graph(sliver=sliver, rid=str(self.rid),
-                                      reservation_state=self.state.name)
+                                      reservation_state=self.state.name,
+                                      error_message=error_message)
         self.logger.debug(f"Update ASM completed for  Reservation# {self.rid} State# {self.get_reservation_state()} "
                           f"Slice Graph# {self.slice.get_graph_id()}")
 
