@@ -29,10 +29,9 @@ from datetime import datetime
 from fabric_cf.actor.core.apis.abc_actor_mixin import ABCActorMixin
 from fabric_cf.actor.core.apis.abc_callback_proxy import ABCCallbackProxy
 from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
-from fabric_cf.actor.core.apis.abc_slice import ABCSlice
 from fabric_cf.actor.core.kernel.failed_rpc import FailedRPC
-from fabric_cf.actor.core.apis.abc_kernel_server_reservation import ABCKernelServerReservationMixin
-from fabric_cf.actor.core.apis.abc_kernel_slice import ABCKernelSlice
+from fabric_cf.actor.core.apis.abc_server_reservation import ABCServerReservation
+from fabric_cf.actor.core.apis.abc_slice import ABCSlice
 from fabric_cf.actor.core.kernel.reservation import Reservation
 from fabric_cf.actor.core.kernel.reservation_states import ReservationPendingStates, ReservationStates
 from fabric_cf.actor.core.kernel.resource_set import ResourceSet
@@ -45,7 +44,7 @@ from fabric_cf.actor.core.util.update_data import UpdateData
 from fabric_cf.actor.security.auth_token import AuthToken
 
 
-class ReservationServer(Reservation, ABCKernelServerReservationMixin):
+class ReservationServer(Reservation, ABCServerReservation):
     """
     Implementation note on error handling. There are several kinds of errors,
     all of which are logged: - Error on an incoming operation, caught with no
@@ -63,7 +62,7 @@ class ReservationServer(Reservation, ABCKernelServerReservationMixin):
     classes to reflect this convention.
     """
 
-    def __init__(self, *, rid: ID, resources: ResourceSet, term: Term, slice_object: ABCKernelSlice):
+    def __init__(self, *, rid: ID, resources: ResourceSet, term: Term, slice_object: ABCSlice):
         super().__init__(rid=rid, slice_object=slice_object)
         # Sequence number for incoming messages.
         self.sequence_in = 0
@@ -230,8 +229,8 @@ class ReservationServer(Reservation, ABCKernelServerReservationMixin):
         Fail and notify
         @param message message
         """
-        self.generate_update()
         self.fail(message=message)
+        self.generate_update()
 
     def fail_warn(self, *, message: str):
         self.update_data.error(message=message)
