@@ -29,16 +29,17 @@ from datetime import datetime
 
 from fim.slivers.base_sliver import BaseSliver
 
-from fabric_cf.actor.core.apis.i_base_plugin import IBasePlugin
-from fabric_cf.actor.core.apis.i_reservation import IReservation
+from fabric_cf.actor.core.apis.abc_base_plugin import ABCBasePlugin
+from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.common.exceptions import ResourcesException
+from fabric_cf.actor.core.util.utils import sliver_to_str
 
 if TYPE_CHECKING:
     from fabric_cf.actor.core.time.term import Term
     from fabric_cf.actor.core.util.id import ID
     from fabric_cf.actor.core.util.notice import Notice
-    from fabric_cf.actor.core.apis.i_concrete_set import IConcreteSet
+    from fabric_cf.actor.core.apis.abc_concrete_set import ABCConcreteSet
     from fabric_cf.actor.core.util.resource_type import ResourceType
 
 
@@ -49,50 +50,10 @@ class ResourceSet:
     ResourceSet with an attached ConcreteSet is "concrete." The ConcreteSet binds
     real resources (or a promise) for some or all of the abstract units in the
     set: for example, a concrete ResourceSet can represent a ticket or
-    lease. Adding or removing concrete resources does not affect the number of
-    abstract units. If there are fewer concrete units than abstract units, the
-    set has a "deficit".
-
-    An "elastic" ResourceSet may be filled at less than its full request, and it
-    may change size on extends. An actor may modify an elastic ResourceSet on an
-    active ReservationClient by calling "flex", if there is no pending operation
-    in progress, e.g., in preparation for an elastic extend. This class updates
-    the unit count to match the concrete resources on each reserve or extend (on
-    a server), or update (on a client).
-
-    Operations on the ConcreteSet through this class may drive probes and state
-    transitions on the underlying resources transferred in and out of the
-    ResourceSet (e.g., node configuration and node reboot for a COD authority, or
-    resource membership changes on a orchestrator). ConcreteSets are
-    responsible for their own synchronization: calls to ConcreteSet go through
-    pre-op "prepare" or post-op "service" methods in this class, which may block
-    and should not hold any higher-level locks. Most other operations are called
-    through Mapper or the Reservation class with the Manager lock held.
-
-    Implementation notes
-    The unit count is updated immediately to reflect additions or deletions
-    from the set. Updates to the unit count must occur only in the locked
-    methods. Configuration actions on the ConcreteSet (e.g., as resources join
-    and leave the set) must occur only in unlocked methods (e.g., "service"). A
-    tricky part is flex(), which updates abstract count to reflect a new request:
-    it is unlocked, which could race with an incoming unsolicited lease (which
-    are currently allowed), or with overlapping requests on the same set (which
-    are currently not allowed).
-    ResourceSet was conceived as supporting methods that are independent of
-    context and type of ConcreteSet. That ideal has eroded somewhat, and some key
-    fields and methods are specific to a particular context or role. Someday it
-    may be useful to break this into subclasses.
-    Currently leases are validated only with validateIncoming(). There may be
-    some additional checks to enforce.
-    No changes to ResourceData on merges. Needs thought and documentation. We
-    should remove the properties argument on ConcreteSet.change.
-    The 'null ticket corner case' (see above) is a source of complexity, and
-    should be cleaned up.
-    Calls that "reach around" ResourceSet to the concrete set are
-    discouraged/deprecated.
+    lease.
     """
-    def __init__(self, *, concrete: IConcreteSet = None, gained: IConcreteSet = None,
-                 lost: IConcreteSet = None, modified: IConcreteSet = None,
+    def __init__(self, *, concrete: ABCConcreteSet = None, gained: ABCConcreteSet = None,
+                 lost: ABCConcreteSet = None, modified: ABCConcreteSet = None,
                  rtype: ResourceType = None, sliver: BaseSliver = None, units: int = None):
         # What type of resources does this set contain. The meaning/assignment of
         # type values is an externally defined convention of interacting actors.
@@ -157,7 +118,7 @@ class ResourceSet:
         self.rid = None
         self.is_closing = False
 
-    def restore(self, *, plugin: IBasePlugin, reservation: IReservation):
+    def restore(self, *, plugin: ABCBasePlugin, reservation: ABCReservationMixin):
         """
         Restore post stateful restart
         @param plugin plugin
@@ -193,7 +154,7 @@ class ResourceSet:
             self.released = None
         return result
 
-    def merge_properties(self, *, reservation: IReservation, resource_set):
+    def merge_properties(self, *, reservation: ABCReservationMixin, resource_set):
         """
         Merge properties
         @param reservation reservation
@@ -204,7 +165,7 @@ class ResourceSet:
 
         self.sliver = resource_set.get_sliver()
 
-    def delta_update(self, *, reservation: IReservation, resource_set):
+    def delta_update(self, *, reservation: ABCReservationMixin, resource_set):
         if reservation is None or resource_set is None:
             raise ResourcesException(Constants.INVALID_ARGUMENT)
 
@@ -254,7 +215,7 @@ class ResourceSet:
         else:
             self.units = 0
 
-    def full_update(self, *, reservation: IReservation, resource_set):
+    def full_update(self, *, reservation: ABCReservationMixin, resource_set):
         if reservation is None or resource_set is None:
             raise ResourcesException(Constants.INVALID_ARGUMENT)
 
@@ -323,7 +284,7 @@ class ResourceSet:
         """
         return self.rid
 
-    def get_resources(self) -> IConcreteSet:
+    def get_resources(self) -> ABCConcreteSet:
         """
         Returns the concrete resources.
         @returns concrete resource set
@@ -443,7 +404,7 @@ class ResourceSet:
         if my_lost is not None:
             self.resources.remove(concrete_set=my_lost, configure=True)
         if my_modified is not None:
-            self.resources.modify(concrete_set=my_modified, configure=True)
+            self.resources.modify(sliver=self.sliver)
 
     def service_modify(self):
         """
@@ -451,7 +412,7 @@ class ResourceSet:
         @raises Exception in case of error
         """
         self.service_check()
-        self.resources.modify(concrete_set=self.resources, configure=True)
+        self.resources.modify(sliver=self.sliver)
 
     def service_reserve_site(self):
         cs = None
@@ -462,7 +423,7 @@ class ResourceSet:
         if cs is not None:
             self.resources.add(concrete_set=cs, configure=True)
 
-    def service_update(self, *, reservation: IReservation):
+    def service_update(self, *, reservation: ABCReservationMixin):
         """
         Service a resource set update. Any changes to existing
         concrete resources should have been left in "updated" by an update
@@ -491,7 +452,7 @@ class ResourceSet:
         """
         self.rid = rid
 
-    def set_resources(self, *, cset: IConcreteSet):
+    def set_resources(self, *, cset: ABCConcreteSet):
         """
         Set the concrete resources. Used by proxies.
         @params cset :concrete resource set
@@ -512,7 +473,7 @@ class ResourceSet:
         """
         self.units = units
 
-    def setup(self, *, reservation: IReservation):
+    def setup(self, *, reservation: ABCReservationMixin):
         """
         Passes information about the containing reservation to the concrete set.
         @params reservation: containing reservation
@@ -521,14 +482,12 @@ class ResourceSet:
             self.resources.setup(reservation=reservation)
 
     def __str__(self):
-        result = "rset: units=[{}] ".format(self.units)
+        result = f"rset: units=[{self.units}] "
         if self.resources is not None:
-            result += " concrete:[{}]".format(self.resources)
-        if self.sliver is not None:
-            result += " sliver: [{}]".format(self.sliver)
+            result += f" concrete:[{self.resources}]"
         return result
 
-    def update(self, *, reservation: IReservation, resource_set: ResourceSet):
+    def update(self, *, reservation: ABCReservationMixin, resource_set: ResourceSet):
         if reservation is None or resource_set is None:
             raise ResourcesException(Constants.INVALID_ARGUMENT)
 
@@ -537,7 +496,7 @@ class ResourceSet:
         else:
             self.delta_update(reservation=reservation, resource_set=resource_set)
 
-    def update_properties(self, *, reservation: IReservation, resource_set):
+    def update_properties(self, *, reservation: ABCReservationMixin, resource_set):
         if reservation is None or resource_set is None:
             raise ResourcesException(Constants.INVALID_ARGUMENT)
 
