@@ -25,7 +25,7 @@
 # Author: Komal Thareja (kthare10@renci.org)
 import enum
 from enum import Enum
-from typing import Tuple
+from typing import Tuple, List
 
 from fabric_cf.actor.core.common.exceptions import SliceException
 from fabric_cf.actor.core.kernel.reservation_states import ReservationStates, ReservationPendingStates
@@ -42,6 +42,40 @@ class SliceState(Enum):
     Closing = enum.auto()
     Dead = enum.auto()
 
+    def __str__(self):
+        return self.name
+
+    @staticmethod
+    def state_from_str(state: str):
+        if state is None:
+            return state
+
+        for t in SliceState:
+            if state == str(t):
+                return t
+
+        return None
+
+    @staticmethod
+    def str_list_to_state_list(states: List[str]) -> list or None:
+        if states is None or len(states) == 0:
+            return states
+
+        result = [SliceState.StableOK, SliceState.StableError, SliceState.Dead,
+                  SliceState.Closing, SliceState.Configuring, SliceState.Nascent]
+        states_to_exclude = []
+        for s in result:
+            if str(s) not in states:
+                states_to_exclude.append(s)
+
+        for s in states_to_exclude:
+            result.remove(s)
+
+        ret_val = []
+        for x in result:
+            ret_val.append(x.value)
+        return ret_val
+
 
 class SliceCommand(Enum):
     Create = enum.auto()
