@@ -25,11 +25,10 @@
 # Author: Komal Thareja (kthare10@renci.org)
 from __future__ import annotations
 
-from datetime import date, datetime
+from datetime import datetime, timezone
 from typing import TYPE_CHECKING, List
 
 from fabric_mb.message_bus.messages.reservation_mng import ReservationMng
-from fabric_mb.message_bus.messages.reservation_state_avro import ReservationStateAvro
 from fabric_mb.message_bus.messages.result_delegation_avro import ResultDelegationAvro
 from fabric_mb.message_bus.messages.result_reservation_avro import ResultReservationAvro
 from fabric_mb.message_bus.messages.result_reservation_state_avro import ResultReservationStateAvro
@@ -42,15 +41,13 @@ from fabric_cf.actor.core.apis.abc_actor_runnable import ABCActorRunnable
 from fabric_cf.actor.core.common.constants import Constants, ErrorCodes
 from fabric_cf.actor.core.common.exceptions import ReservationNotFoundException, SliceNotFoundException, \
     DelegationNotFoundException, ManageException
-from fabric_cf.actor.core.kernel.reservation_states import ReservationStates, ReservationPendingStates
 from fabric_cf.actor.core.kernel.slice import SliceFactory
 from fabric_cf.actor.core.manage.converter import Converter
 from fabric_cf.actor.core.manage.management_object import ManagementObject
 from fabric_cf.actor.core.manage.management_utils import ManagementUtils
 from fabric_cf.actor.core.manage.proxy_protocol_descriptor import ProxyProtocolDescriptor
 from fabric_cf.actor.core.apis.abc_actor_management_object import ABCActorManagementObject
-from fabric_cf.actor.security.access_checker import AccessChecker
-from fabric_cf.actor.security.pdp_auth import ActionId, ResourceType
+
 from fabric_cf.actor.core.proxies.kafka.translate import Translate
 from fabric_cf.actor.core.registry.actor_registry import ActorRegistrySingleton
 from fabric_cf.actor.core.util.id import ID
@@ -110,8 +107,8 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             self.logger = actor.get_logger()
             self.id = actor.get_guid()
 
-    def get_slices(self, *, slice_id: ID, caller: AuthToken, id_token: str = None,
-                   slice_name: str = None, email: str = None) -> ResultSliceAvro:
+    def get_slices(self, *, slice_id: ID, caller: AuthToken, slice_name: str = None,
+                   email: str = None, state: List[int] = None, project: str = None) -> ResultSliceAvro:
         result = ResultSliceAvro()
         result.status = ResultAvro()
 
@@ -120,39 +117,11 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             result.status.set_message(ErrorCodes.ErrorInvalidArguments.interpret())
         else:
             slice_list = None
-            user_dn = None
-            user_email = email
+
             try:
-                if id_token is not None:
-                    fabric_token = AccessChecker.check_access(action_id=ActionId.query, resource_type=ResourceType.slice,
-                                                              token=id_token, logger=self.logger,
-                                                              actor_type=self.actor.get_type(),
-                                                              resource_id=str(slice_id))
-                    user_dn = fabric_token.get_decoded_token().get(Constants.CLAIMS_SUB, None)
-                    user_email = fabric_token.get_decoded_token().get(Constants.CLAIMS_EMAIL, None)
-
-                    if user_dn is None:
-                        result.status.set_code(ErrorCodes.ErrorInvalidToken.value)
-                        result.status.set_message(ErrorCodes.ErrorInvalidToken.interpret())
-                        return result
-
                 try:
-                    slice_list = None
-                    if slice_id is not None:
-                        slice_obj = self.db.get_slice(slice_id=slice_id)
-                        if slice_obj is not None:
-                            slice_list = [slice_obj]
-
-                    elif slice_name is not None:
-                        slice_list = self.db.get_slice_by_name(slice_name=slice_name, oidc_claim_sub=user_dn,
-                                                               email=user_email)
-                    elif user_dn is not None:
-                        slice_list = self.db.get_slice_by_oidc_claim_sub(oidc_claim_sub=user_dn)
-                    elif user_email is not None:
-                        slice_list = self.db.get_slice_by_email(email=user_email)
-                    else:
-                        slice_list = self.db.get_slices()
-
+                    slice_list = self.db.get_slices(slice_id=slice_id, slice_name=slice_name, email=email,
+                                                    state=state, project_id=project)
                 except Exception as e:
                     self.logger.error("getSlices:db access {}".format(e))
                     result.status.set_code(ErrorCodes.ErrorDatabaseError.value)
@@ -170,7 +139,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
                 result.status = ManagementObject.set_exception_details(result=result.status, e=e)
         return result
 
-    def add_slice(self, *, slice_obj: SliceAvro, caller: AuthToken, id_token: str = None) -> ResultStringAvro:
+    def add_slice(self, *, slice_obj: SliceAvro, caller: AuthToken) -> ResultStringAvro:
         result = ResultStringAvro()
         result.status = ResultAvro()
 
@@ -180,32 +149,18 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         else:
             try:
-                user_dn = None
-                user_email = None
-                if id_token is not None:
-                    fabric_token = AccessChecker.check_access(action_id=ActionId.query,
-                                                              resource_type=ResourceType.slice,
-                                                              token=id_token, logger=self.logger,
-                                                              actor_type=self.actor.get_type(),
-                                                              resource_id=str(slice_obj.slice_name))
-                    user_dn = fabric_token.get_decoded_token().get(Constants.CLAIMS_SUB, None)
-                    user_email = fabric_token.get_decoded_token().get(Constants.CLAIMS_EMAIL, None)
-
-                    if user_dn is None:
-                        result.status.set_code(ErrorCodes.ErrorInvalidToken.value)
-                        result.status.set_message(ErrorCodes.ErrorInvalidToken.interpret())
-                        return result
 
                 slice_obj_new = SliceFactory.create(slice_id=ID(), name=slice_obj.get_slice_name())
-
                 slice_obj_new.set_description(description=slice_obj.get_description())
                 slice_obj_new.set_owner(owner=self.actor.get_identity())
-                slice_obj_new.get_owner().set_oidc_sub_claim(oidc_sub_claim=user_dn)
-                slice_obj_new.get_owner().set_email(email=user_email)
+                slice_obj_new.get_owner().set_oidc_sub_claim(oidc_sub_claim=slice_obj.get_owner().get_oidc_sub_claim())
+                slice_obj_new.get_owner().set_email(email=slice_obj.get_owner().get_email())
+                slice_obj_new.get_owner().set_token(token=slice_obj.get_owner().get_token())
                 slice_obj_new.set_graph_id(graph_id=slice_obj.graph_id)
                 slice_obj_new.set_config_properties(value=slice_obj.get_config_properties())
                 slice_obj_new.set_lease_end(lease_end=slice_obj.get_lease_end())
-                slice_obj_new.set_lease_start(lease_start=datetime.utcnow())
+                slice_obj_new.set_lease_start(lease_start=datetime.now(timezone.utc))
+                slice_obj_new.set_project_id(project_id=slice_obj.get_project_id())
 
                 if slice_obj.get_inventory():
                     slice_obj_new.set_inventory(value=True)
@@ -240,7 +195,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         return result
 
-    def remove_slice(self, *, slice_id: ID, caller: AuthToken, id_token: str = None) -> ResultAvro:
+    def remove_slice(self, *, slice_id: ID, caller: AuthToken) -> ResultAvro:
         result = ResultAvro()
         if slice_id is None or caller is None:
             result.set_code(ErrorCodes.ErrorInvalidArguments.value)
@@ -248,12 +203,6 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.delete,
-                                           resource_type=ResourceType.slice,
-                                           token=id_token, logger=self.logger,
-                                           actor_type=self.actor.get_type(),
-                                           resource_id=str(slice_id))
 
             class Runner(ABCActorRunnable):
                 def __init__(self, *, actor: ABCActorMixin):
@@ -298,7 +247,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
                     try:
                         self.actor.get_plugin().get_database().update_slice(slice_object=slice_obj)
                     except Exception as e:
-                        print("Could not commit slice update {}".format(e))
+                        self.actor.get_logger().error("Could not commit slice update {}".format(e))
                         result.set_code(ErrorCodes.ErrorDatabaseError.value)
                         result.set_message(ErrorCodes.ErrorDatabaseError.interpret(exception=e))
                         result = ManagementObject.set_exception_details(result=result, e=e)
@@ -314,13 +263,15 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         return result
 
-    def get_slice_by_guid(self, *, guid: str, id_token: str = None) -> ABCSlice:
-        return self.db.get_slice(slice_id=guid)
+    def get_slice_by_guid(self, *, guid: str) -> ABCSlice or None:
+        slices = self.db.get_slices(slice_id=guid)
+        if len(slices) == 0:
+            return None
+        return slices[0]
 
-    def get_reservations(self, *, caller: AuthToken, id_token: str = None, state: int = None,
+    def get_reservations(self, *, caller: AuthToken, state: List[int] = None,
                          slice_id: ID = None, rid: ID = None, oidc_claim_sub: str = None,
-                         email: str = None, rid_list: List[str] = None,
-                         notices_as_dict: bool = False) -> ResultReservationAvro:
+                         email: str = None, rid_list: List[str] = None) -> ResultReservationAvro:
         result = ResultReservationAvro()
         result.status = ResultAvro()
 
@@ -330,47 +281,14 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             return result
 
         try:
-            user_dn = oidc_claim_sub
-            user_email = email
-            if id_token is not None:
-                fabric_token = AccessChecker.check_access(action_id=ActionId.query, resource_type=ResourceType.sliver,
-                                                          token=id_token, logger=self.logger,
-                                                          actor_type=self.actor.get_type(),
-                                                          resource_id=str(rid))
-                user_dn = fabric_token.get_decoded_token().get(Constants.CLAIMS_SUB, None)
-                user_email = fabric_token.get_decoded_token().get(Constants.CLAIMS_EMAIL, None)
-
-                if user_dn is None:
-                    result.status.set_code(ErrorCodes.ErrorInvalidToken.value)
-                    result.status.set_message(ErrorCodes.ErrorInvalidToken.interpret())
-                    return result
 
             res_list = None
             try:
-                if rid is not None:
-                    res = self.db.get_reservation(rid=rid)
-                    if res is not None:
-                        res_list = [res]
-                    else:
-                        result.status.set_code(ErrorCodes.ErrorNoSuchReservation.value)
-                        result.status.set_message(ErrorCodes.ErrorNoSuchReservation.interpret())
-                elif slice_id is not None and state is not None:
-                    res_list = self.db.get_reservations_by_slice_id_state(slice_id=slice_id, state=state)
-                elif slice_id is not None:
-                    res_list = self.db.get_reservations_by_slice_id(slice_id=slice_id)
-                elif state is not None:
-                    res_list = self.db.get_reservations_by_state(state=state)
-                elif user_dn is not None:
-                    res_list = self.db.get_reservations_by_oidc_claim_sub(oidc_claim_sub=user_dn)
-                elif user_email is not None:
-                    if state is None:
-                        res_list = self.db.get_reservations_by_email(email=user_email)
-                    else:
-                        res_list = self.db.get_reservations_by_email_state(email=user_email, state=state)
-                elif rid_list is not None:
+                if rid_list is not None:
                     res_list = self.db.get_reservations_by_rids(rid=rid_list)
                 else:
-                    res_list = self.db.get_reservations()
+                    res_list = self.db.get_reservations(slice_id=slice_id, rid=rid, email=email,
+                                                        oidc_sub=oidc_claim_sub, state=state)
             except Exception as e:
                 self.logger.error("getReservations:db access {}".format(e))
                 result.status.set_code(ErrorCodes.ErrorDatabaseError.value)
@@ -383,7 +301,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
                     slice_id = r.get_slice_id()
                     slice_obj = self.get_slice_by_guid(guid=slice_id)
                     r.restore(actor=self.actor, slice_obj=slice_obj)
-                    rr = Converter.fill_reservation(reservation=r, full=True, notices_as_dict=notices_as_dict)
+                    rr = Converter.fill_reservation(reservation=r, full=True)
                     result.reservations.append(rr)
         except ReservationNotFoundException as e:
             self.logger.error("getReservations: {}".format(e))
@@ -397,7 +315,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         return result
 
-    def remove_reservation(self, *, caller: AuthToken, rid: ID, id_token: str = None) -> ResultAvro:
+    def remove_reservation(self, *, caller: AuthToken, rid: ID) -> ResultAvro:
         result = ResultAvro()
 
         if rid is None or caller is None:
@@ -406,12 +324,6 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.delete,
-                                           resource_type=ResourceType.sliver,
-                                           token=id_token, logger=self.logger,
-                                           actor_type=self.actor.get_type(),
-                                           resource_id=str(rid))
 
             class Runner(ABCActorRunnable):
                 def __init__(self, *, actor: ABCActorMixin):
@@ -434,7 +346,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         return result
 
-    def close_reservation(self, *, caller: AuthToken, rid: ID, id_token: str = None) -> ResultAvro:
+    def close_reservation(self, *, caller: AuthToken, rid: ID) -> ResultAvro:
         result = ResultAvro()
 
         if rid is None or caller is None:
@@ -443,13 +355,6 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.close,
-                                           resource_type=ResourceType.sliver,
-                                           token=id_token, logger=self.logger,
-                                           actor_type=self.actor.get_type(),
-                                           resource_id=str(rid))
-
             class Runner(ABCActorRunnable):
                 def __init__(self, *, actor: ABCActorMixin):
                     self.actor = actor
@@ -471,7 +376,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         return result
 
-    def close_slice_reservations(self, *, caller: AuthToken, slice_id: ID, id_token: str = None) -> ResultAvro:
+    def close_slice_reservations(self, *, caller: AuthToken, slice_id: ID) -> ResultAvro:
         result = ResultAvro()
 
         if slice_id is None or caller is None:
@@ -480,13 +385,6 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.close,
-                                           resource_type=ResourceType.slice,
-                                           token=id_token, logger=self.logger,
-                                           actor_type=self.actor.get_type(),
-                                           resource_id=str(slice_id))
-
             class Runner(ABCActorRunnable):
                 def __init__(self, *, actor: ABCActorMixin):
                     self.actor = actor
@@ -511,7 +409,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
     def get_actor(self) -> ABCActorMixin:
         return self.actor
 
-    def get_actor_name(self) -> str:
+    def get_actor_name(self) -> str or None:
         if self.actor is not None:
             return self.actor.get_name()
 
@@ -544,7 +442,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
                     try:
                         self.actor.get_plugin().get_database().update_reservation(reservation=r)
                     except Exception as e:
-                        print("Could not commit slice update {}".format(e))
+                        self.actor.get_logger().error("Could not commit slice update {}".format(e))
                         result.set_code(ErrorCodes.ErrorDatabaseError.value)
                         result.set_message(ErrorCodes.ErrorDatabaseError.interpret(exception=e))
                         result = ManagementObject.set_exception_details(result=result, e=e)
@@ -563,8 +461,8 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         return result
 
-    def get_reservation_state_for_reservations(self, *, caller: AuthToken, rids: List[str],
-                                               id_token: str = None) -> ResultReservationStateAvro:
+    def get_reservation_state_for_reservations(self, *, caller: AuthToken,
+                                               rids: List[str]) -> ResultReservationStateAvro:
         result = ResultReservationStateAvro()
         result.status = ResultAvro()
 
@@ -580,9 +478,6 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
                 return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.query, resource_type=ResourceType.sliver,
-                                           token=id_token, logger=self.logger, actor_type=self.actor.get_type())
 
             res_list = None
             try:
@@ -610,8 +505,8 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
 
         return result
 
-    def get_delegations(self, *, caller: AuthToken, id_token: str = None, slice_id: ID = None,
-                        did: str = None, state: int = None) -> ResultDelegationAvro:
+    def get_delegations(self, *, caller: AuthToken, slice_id: ID = None, did: str = None,
+                        state: int = None) -> ResultDelegationAvro:
         result = ResultDelegationAvro()
         result.status = ResultAvro()
 
@@ -621,9 +516,7 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.query, resource_type=ResourceType.delegation,
-                                           token=id_token, logger=self.logger, actor_type=self.actor.get_type())
+
             dlg_list = None
             try:
                 if did is not None:
@@ -633,10 +526,8 @@ class ActorManagementObject(ManagementObject, ABCActorManagementObject):
                     else:
                         result.status.set_code(ErrorCodes.ErrorNoSuchDelegation.value)
                         result.status.set_message(ErrorCodes.ErrorNoSuchDelegation.interpret())
-                elif slice_id is not None:
-                    dlg_list = self.db.get_delegations_by_slice_id(slice_id=slice_id, state=state)
                 else:
-                    dlg_list = self.db.get_delegations(state=state)
+                    dlg_list = self.db.get_delegations(slice_id=slice_id, state=state)
             except Exception as e:
                 self.logger.error("get_delegations db access {}".format(e))
                 result.status.set_code(ErrorCodes.ErrorDatabaseError.value)
