@@ -30,6 +30,7 @@ from typing import TYPE_CHECKING, List
 
 from fabric_mb.message_bus.messages.proxy_avro import ProxyAvro
 from fabric_mb.message_bus.messages.result_delegation_avro import ResultDelegationAvro
+from fim.user import GraphFormat
 
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.manage.client_actor_management_object_helper import ClientActorManagementObjectHelper
@@ -84,15 +85,16 @@ class BrokerManagementObject(ServerActorManagementObject, ABCClientActorManageme
             super().set_actor(actor=actor)
             self.client_helper = ClientActorManagementObjectHelper(client=actor)
 
-    def get_brokers(self, *, caller: AuthToken, broker_id: ID = None, id_token: str = None) -> ResultProxyAvro:
-        return self.client_helper.get_brokers(caller=caller, id_token=id_token, broker_id=broker_id)
+    def get_brokers(self, *, caller: AuthToken, broker_id: ID = None) -> ResultProxyAvro:
+        return self.client_helper.get_brokers(caller=caller, broker_id=broker_id)
 
     def add_broker(self, *, broker: ProxyAvro, caller: AuthToken) -> ResultAvro:
         return self.client_helper.add_broker(broker=broker, caller=caller)
 
     def get_broker_query_model(self, *, broker: ID, caller: AuthToken, id_token: str,
-                               level: int) -> ResultBrokerQueryModelAvro:
-        return self.client_helper.get_broker_query_model(broker=broker, caller=caller, id_token=id_token, level=level)
+                               level: int, graph_format: GraphFormat) -> ResultBrokerQueryModelAvro:
+        return self.client_helper.get_broker_query_model(broker=broker, caller=caller, id_token=id_token, level=level,
+                                                         graph_format=graph_format)
 
     def add_reservation(self, *, reservation: TicketReservationAvro, caller: AuthToken) -> ResultStringAvro:
         return self.client_helper.add_reservation(reservation=reservation, caller=caller)
@@ -111,10 +113,8 @@ class BrokerManagementObject(ServerActorManagementObject, ABCClientActorManageme
         return self.client_helper.extend_reservation(reservation=reservation, new_end_time=new_end_time,
                                                      new_units=new_units, caller=caller)
 
-    def claim_delegations(self, *, broker: ID, did: str, caller: AuthToken,
-                          id_token: str = None) -> ResultDelegationAvro:
-        return self.client_helper.claim_delegations(broker=broker, did=did, caller=caller, id_token=id_token)
+    def claim_delegations(self, *, broker: ID, did: str, caller: AuthToken) -> ResultDelegationAvro:
+        return self.client_helper.claim_delegations(broker=broker, did=did, caller=caller)
 
-    def reclaim_delegations(self, *, broker: ID, did: str, caller: AuthToken,
-                            id_token: str = None) -> ResultDelegationAvro:
-        return self.client_helper.reclaim_delegations(broker=broker, did=did, caller=caller, id_token=id_token)
\ No newline at end of file
+    def reclaim_delegations(self, *, broker: ID, did: str, caller: AuthToken) -> ResultDelegationAvro:
+        return self.client_helper.reclaim_delegations(broker=broker, did=did, caller=caller)
\ No newline at end of file
