@@ -27,7 +27,7 @@ from __future__ import annotations
 
 import traceback
 from datetime import datetime
-from typing import TYPE_CHECKING, List
+from typing import TYPE_CHECKING, List, Tuple
 
 from fabric_mb.message_bus.messages.lease_reservation_avro import LeaseReservationAvro
 from fabric_mb.message_bus.messages.result_delegation_avro import ResultDelegationAvro
@@ -37,7 +37,8 @@ from fabric_mb.message_bus.messages.result_reservation_avro import ResultReserva
 from fabric_mb.message_bus.messages.result_string_avro import ResultStringAvro
 from fabric_mb.message_bus.messages.result_strings_avro import ResultStringsAvro
 from fabric_mb.message_bus.messages.result_avro import ResultAvro
-
+from fim.slivers.base_sliver import BaseSliver
+from fim.user import GraphFormat
 
 from fabric_cf.actor.core.apis.abc_actor_runnable import ABCActorRunnable
 from fabric_cf.actor.core.apis.abc_controller_reservation import ABCControllerReservation
@@ -75,7 +76,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
         from fabric_cf.actor.core.container.globals import GlobalsSingleton
         self.logger = GlobalsSingleton.get().get_logger()
 
-    def get_brokers(self, *, caller: AuthToken, broker_id: ID = None, id_token: str = None) -> ResultProxyAvro:
+    def get_brokers(self, *, caller: AuthToken, broker_id: ID = None) -> ResultProxyAvro:
         result = ResultProxyAvro()
         result.status = ResultAvro()
 
@@ -130,7 +131,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
         return result
 
     def get_broker_query_model(self, *, broker: ID, caller: AuthToken, id_token: str,
-                               level: int) -> ResultBrokerQueryModelAvro:
+                               level: int, graph_format: GraphFormat) -> ResultBrokerQueryModelAvro:
         result = ResultBrokerQueryModelAvro()
         result.status = ResultAvro()
 
@@ -140,14 +141,11 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.query, resource_type=AuthResourceType.resources,
-                                           token=id_token, logger=self.logger, actor_type=self.client.get_type())
 
             b = self.client.get_broker(guid=broker)
             if b is not None:
-                request = BrokerPolicy.get_broker_query_model_query(level=level)
-                response = ManagementUtils.query(actor=self.client, actor_proxy=b, query=request, id_token=id_token)
+                request = BrokerPolicy.get_broker_query_model_query(level=level, bqm_format=graph_format)
+                response = ManagementUtils.query(actor=self.client, actor_proxy=b, query=request)
                 result.model = Translate.translate_to_broker_query_model(query_response=response, level=level)
             else:
                 result.status.set_code(ErrorCodes.ErrorNoSuchBroker.value)
@@ -172,7 +170,12 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
         if reservation.get_broker() is not None:
             broker = ID(uid=reservation.get_broker())
 
-        rc = ClientReservationFactory.create(rid=ID(), resources=rset, term=term)
+        rid = None
+        if reservation.get_reservation_id() is not None:
+            rid = ID(uid=reservation.get_reservation_id())
+        else:
+            rid = ID()
+        rc = ClientReservationFactory.create(rid=rid, resources=rset, term=term)
         rc.set_renewable(renewable=reservation.is_renewable())
 
         if rc.get_state() != ReservationStates.Nascent or rc.get_pending_state() != ReservationPendingStates.None_:
@@ -293,7 +296,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
 
         try:
             class Runner(ABCActorRunnable):
-                def __init__(self, *, actor: ABCActorMixin):
+                def __init__(self, *, actor: ABCClientActor):
                     self.actor = actor
 
                 def run(self):
@@ -319,7 +322,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
 
         try:
             class Runner(ABCActorRunnable):
-                def __init__(self, *, actor: ABCActorMixin, logger):
+                def __init__(self, *, actor: ABCClientActor, logger):
                     self.actor = actor
                     self.logger = logger
 
@@ -354,15 +357,9 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
                                                     "class={}".format(rid, type(pr)))
                                 continue
 
-                            ff = pred.get_filter()
-                            if ff is not None:
-                                self.logger.debug("Setting redeem predecessor on reservation # {} pred={} filter={}".
-                                                  format(r.get_reservation_id(), pr.get_reservation_id(), ff))
-                                r.add_redeem_predecessor(reservation=pr, filter=ff)
-                            else:
-                                self.logger.debug("Setting redeem predecessor on reservation # {} pred={} filter=none".
-                                                  format(r.get_reservation_id(), pr.get_reservation_id()))
-                                r.add_redeem_predecessor(reservation=pr)
+                            self.logger.debug("Setting redeem predecessor on reservation # {} pred={}".
+                                              format(r.get_reservation_id(), pr.get_reservation_id()))
+                            r.add_redeem_predecessor(reservation=pr)
 
                     try:
                         self.actor.get_plugin().get_database().update_reservation(reservation=r)
@@ -436,19 +433,19 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
 
         return result
 
-    def modify_reservation(self, *, rid: ID, modify_properties: dict, caller: AuthToken) -> ResultAvro:
+    def modify_reservation(self, *, rid: ID, modified_sliver: BaseSliver, caller: AuthToken) -> ResultAvro:
         result = ResultAvro()
 
-        if rid is None or modify_properties is None:
+        if rid is None or modified_sliver is None:
             result.set_code(ErrorCodes.ErrorInvalidArguments.value)
             result.set_message(ErrorCodes.ErrorInvalidArguments.interpret())
             return result
 
-        self.logger.debug("reservation: {} | modifyProperties= {}".format(rid, modify_properties))
+        self.logger.debug("reservation: {} | modified_sliver= {}".format(rid, modified_sliver))
         try:
 
             class Runner(ABCActorRunnable):
-                def __init__(self, *, actor: ABCActorMixin):
+                def __init__(self, *, actor: ABCClientActor):
                     self.actor = actor
 
                 def run(self):
@@ -459,7 +456,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
                         result.set_message(ErrorCodes.ErrorNoSuchReservation.interpret())
                         return result
 
-                    self.actor.modify(reservation_id=rid, modify_properties=modify_properties)
+                    self.actor.modify(reservation_id=rid, modified_sliver=modified_sliver)
 
                     return result
             result = self.client.execute_on_actor_thread_and_wait(runnable=Runner(actor=self.client))
@@ -471,8 +468,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
 
         return result
 
-    def claim_delegations(self, *, broker: ID, did: str, caller: AuthToken,
-                          id_token: str = None) -> ResultDelegationAvro:
+    def claim_delegations(self, *, broker: ID, did: str, caller: AuthToken) -> ResultDelegationAvro:
         result = ResultDelegationAvro()
         result.status = ResultAvro()
 
@@ -482,11 +478,6 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.query, resource_type=AuthResourceType.delegation,
-                                           token=id_token, logger=self.logger, actor_type=self.client.get_type(),
-                                           resource_id=did)
-
             my_broker = self.client.get_broker(guid=broker)
 
             if my_broker is None:
@@ -495,7 +486,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
                 return result
 
             class Runner(ABCActorRunnable):
-                def __init__(self, *, actor: ABCActorMixin):
+                def __init__(self, *, actor: ABCClientActor):
                     self.actor = actor
 
                 def run(self):
@@ -518,9 +509,8 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
 
         return result
 
-    def reclaim_delegations(self, *, broker: ID, did: str, caller: AuthToken,
-                            id_token: str = None) -> ResultDelegationAvro:
-        result = ResultReservationAvro()
+    def reclaim_delegations(self, *, broker: ID, did: str, caller: AuthToken) -> ResultDelegationAvro:
+        result = ResultDelegationAvro()
         result.status = ResultAvro()
 
         if caller is None or did is None or broker is None:
@@ -529,10 +519,6 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
             return result
 
         try:
-            if id_token is not None:
-                AccessChecker.check_access(action_id=ActionId.query, resource_type=AuthResourceType.resources,
-                                           token=id_token, logger=self.logger, actor_type=self.client.get_type(),
-                                           resource_id=did)
 
             my_broker = self.client.get_broker(guid=broker)
 
@@ -542,7 +528,7 @@ class ClientActorManagementObjectHelper(ABCClientActorManagementObject):
                 return result
 
             class Runner(ABCActorRunnable):
-                def __init__(self, *, actor: ABCActorMixin):
+                def __init__(self, *, actor: ABCClientActor):
                     self.actor = actor
 
                 def run(self):
