@@ -33,6 +33,8 @@ from fabric_mb.message_bus.messages.delegation_avro import DelegationAvro
 from fabric_mb.message_bus.messages.broker_query_model_avro import BrokerQueryModelAvro
 from fabric_mb.message_bus.messages.ticket_reservation_avro import TicketReservationAvro
 from fabric_mb.message_bus.messages.unit_avro import UnitAvro
+from fim.slivers.base_sliver import BaseSliver
+from fim.user import GraphFormat
 
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.common.exceptions import ManageException
@@ -47,7 +49,6 @@ if TYPE_CHECKING:
 
     from fabric_cf.actor.core.manage.management_object import ManagementObject
     from fabric_cf.actor.security.auth_token import AuthToken
-    from fabric_cf.actor.core.util.resource_type import ResourceType
 
 
 class LocalController(LocalActor, ABCMgmtControllerMixin):
@@ -81,11 +82,12 @@ class LocalController(LocalActor, ABCMgmtControllerMixin):
 
         return None
 
-    def get_broker_query_model(self, *, broker: ID, id_token: str, level: int) -> BrokerQueryModelAvro:
+    def get_broker_query_model(self, *, broker: ID, id_token: str, level: int,
+                               graph_format: GraphFormat) -> BrokerQueryModelAvro:
         self.clear_last()
         try:
             result = self.manager.get_broker_query_model(broker=broker, caller=self.auth, id_token=id_token,
-                                                         level=level)
+                                                         level=level, graph_format=graph_format)
             self.last_status = result.status
 
             if result.status.get_code() == 0:
@@ -98,7 +100,7 @@ class LocalController(LocalActor, ABCMgmtControllerMixin):
     def claim_delegations(self, *, broker: ID, did: ID, id_token: str = None) -> DelegationAvro:
         self.clear_last()
         try:
-            result = self.manager.claim_delegations(broker=broker, did=did, caller=self.auth, id_token=id_token)
+            result = self.manager.claim_delegations(broker=broker, did=did, caller=self.auth)
             self.last_status = result.status
 
             if result.status.get_code() == 0:
@@ -111,7 +113,7 @@ class LocalController(LocalActor, ABCMgmtControllerMixin):
     def reclaim_delegations(self, *, broker: ID, did: ID, id_token: str = None) -> DelegationAvro:
         self.clear_last()
         try:
-            result = self.manager.reclaim_delegations(broker=broker, did=did, caller=self.auth, id_token=id_token)
+            result = self.manager.reclaim_delegations(broker=broker, did=did, caller=self.auth)
             self.last_status = result.status
 
             if result.status.get_code() == 0:
@@ -204,10 +206,10 @@ class LocalController(LocalActor, ABCMgmtControllerMixin):
     def clone(self):
         return LocalController(manager=self.manager, auth=self.auth)
 
-    def modify_reservation(self, *, rid: ID, modify_properties: dict) -> bool:
+    def modify_reservation(self, *, rid: ID, modified_sliver: BaseSliver) -> bool:
         self.clear_last()
         try:
-            result = self.manager.modify_reservation(rid=rid, modify_properties=modify_properties, caller=self.auth)
+            result = self.manager.modify_reservation(rid=rid, modified_sliver=modified_sliver, caller=self.auth)
             self.last_status = result
 
             return result.get_code() == 0
