@@ -90,6 +90,7 @@ class Translate:
         slice_obj.set_config_properties(value=slice_avro.config_properties)
         slice_obj.set_lease_start(lease_start=slice_avro.get_lease_start())
         slice_obj.set_lease_end(lease_end=slice_avro.get_lease_end())
+        slice_obj.set_project_id(project_id=slice_avro.project_id)
         return slice_obj
 
     @staticmethod
@@ -103,6 +104,8 @@ class Translate:
         avro_slice.config_properties = slice_obj.get_config_properties()
         avro_slice.set_lease_end(lease_end=slice_obj.get_lease_end())
         avro_slice.set_lease_start(lease_start=slice_obj.get_lease_start())
+        if slice_obj.__dict__.get('project_id') is not None:
+            avro_slice.set_project_id(project_id=slice_obj.get_project_id())
 
         if slice_obj.get_resource_type() is not None:
             avro_slice.set_resource_type(str(slice_obj.get_resource_type()))
@@ -121,6 +124,8 @@ class Translate:
         result.guid = str(auth.get_guid())
         result.oidc_sub_claim = auth.get_oidc_sub_claim()
         result.email = auth.get_email()
+        if AuthToken.__dict__.get('token') is not None:
+            result.token = auth.get_token()
         return result
 
     @staticmethod
@@ -132,6 +137,7 @@ class Translate:
         result.guid = auth_avro.guid
         result.oidc_sub_claim = auth_avro.oidc_sub_claim
         result.email = auth_avro.email
+        result.token = auth_avro.token
         return result
 
     @staticmethod
