@@ -32,10 +32,64 @@ from fim.slivers.network_service import NetworkServiceSliver, ServiceType
 
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.plugins.handlers.config_token import ConfigToken
+from fabric_cf.actor.core.util.utils import sliver_to_str
 from fabric_cf.actor.handlers.handler_base import HandlerBase
 
 
 class NoOpHandler(HandlerBase):
+    def __process_node_sliver(self, *, sliver: NodeSliver):
+        assert (sliver.label_allocations is not None)
+        assert (sliver.label_allocations.instance_parent is not None)
+        assert (sliver.get_capacity_hints() is not None)
+        assert (sliver.get_capacity_hints().instance_type is not None)
+        assert (sliver.get_image_ref() is not None)
+        assert (sliver.get_name() is not None)
+        assert (sliver.get_type() is not None)
+        if sliver.attached_components_info is not None:
+            for component in sliver.attached_components_info.devices.values():
+                assert (component.label_allocations is not None)
+                assert (component.label_allocations.bdf is not None)
+        sliver.label_allocations.instance = 'instance_001'
+        sliver.management_ip = '1.2.3.4'
+
+        self.get_logger().debug(f"s: {sliver}")
+        nic_types = [ComponentType.SharedNIC, ComponentType.SmartNIC]
+        if sliver.attached_components_info is not None:
+            for c in sliver.attached_components_info.devices.values():
+                if c.get_type() not in nic_types:
+                    continue
+                self.get_logger().debug(f"c: {c}")
+                if c.network_service_info is not None and c.network_service_info.network_services is not None:
+                    for ns in c.network_service_info.network_services.values():
+                        self.get_logger().debug(f"ns: {ns}")
+                        if ns.interface_info is not None and ns.interface_info.interfaces is not None:
+                            for i in ns.interface_info.interfaces.values():
+                                self.get_logger().debug(f"ifs: {i}")
+
+    def __process_ns_sliver(self, *, sliver: NetworkServiceSliver):
+        assert (sliver.get_type() is not None)
+        assert (sliver.interface_info is not None)
+        for interface in sliver.interface_info.interfaces.values():
+            assert (interface.labels is not None)
+            assert (interface.labels.device_name is not None)
+            assert (interface.labels.local_name is not None)
+            assert (interface.capacities is not None)
+
+            if sliver.get_type() == ServiceType.L2PTP:
+                assert (interface.labels.vlan is not None)
+
+            if sliver.get_type() == ServiceType.FABNetv4:
+                assert (sliver.get_gateway() is not None)
+                assert (sliver.get_gateway().lab.ipv4_subnet is not None)
+                assert (sliver.get_gateway().lab.ipv4 is not None)
+                assert (interface.labels.vlan is not None)
+
+            if sliver.get_type() == ServiceType.FABNetv6:
+                assert (sliver.get_gateway() is not None)
+                assert (sliver.get_gateway().lab.ipv6_subnet is not None)
+                assert (sliver.get_gateway().lab.ipv6 is not None)
+                assert (interface.labels.vlan is not None)
+
     def create(self, unit: ConfigToken) -> Tuple[dict, ConfigToken]:
         result = None
         try:
@@ -43,64 +97,14 @@ class NoOpHandler(HandlerBase):
             sliver = unit.get_sliver()
 
             if isinstance(sliver, NodeSliver):
-                assert (sliver.label_allocations is not None)
-                assert (sliver.label_allocations.instance_parent is not None)
-                assert (sliver.get_capacity_hints() is not None)
-                assert (sliver.get_capacity_hints().instance_type is not None)
-                assert (sliver.get_image_ref() is not None)
-                assert (sliver.get_name() is not None)
-                assert (sliver.get_type() is not None)
-                if sliver.attached_components_info is not None:
-                    for component in sliver.attached_components_info.devices.values():
-                        assert (component.label_allocations is not None)
-                        assert (component.label_allocations.bdf is not None)
-                sliver.label_allocations.instance = 'instance_001'
-                sliver.management_ip = '1.2.3.4'
-
-                self.get_logger().debug(f"s: {sliver}")
-                nic_types = [ComponentType.SharedNIC, ComponentType.SmartNIC]
-                if sliver.attached_components_info is not None:
-                    for c in sliver.attached_components_info.devices.values():
-                        if c.get_type() not in nic_types:
-                            continue
-                        self.get_logger().debug(f"c: {c}")
-                        if c.network_service_info is not None and c.network_service_info.network_services is not None:
-                            for ns in c.network_service_info.network_services.values():
-                                self.get_logger().debug(f"ns: {ns}")
-                                if ns.interface_info is not None and ns.interface_info.interfaces is not None:
-                                    for i in ns.interface_info.interfaces.values():
-                                        self.get_logger().debug(f"ifs: {i}")
-                result = {Constants.PROPERTY_TARGET_NAME: Constants.TARGET_CREATE,
-                          Constants.PROPERTY_TARGET_RESULT_CODE: Constants.RESULT_CODE_OK,
-                          Constants.PROPERTY_ACTION_SEQUENCE_NUMBER: 0}
+                self.__process_node_sliver(sliver=sliver)
 
             elif isinstance(sliver, NetworkServiceSliver):
-                assert (sliver.get_type() is not None)
-                assert (sliver.interface_info is not None)
-                for interface in sliver.interface_info.interfaces.values():
-                    assert (interface.labels is not None)
-                    assert (interface.labels.device_name is not None)
-                    assert (interface.labels.local_name is not None)
-                    assert (interface.capacities is not None)
+                self.__process_ns_sliver(sliver=sliver)
 
-                    if sliver.get_type() == ServiceType.L2PTP:
-                        assert (interface.labels.vlan is not None)
-
-                    if sliver.get_type() == ServiceType.FABNetv4:
-                        assert (sliver.get_gateway() is not None)
-                        assert (sliver.get_gateway().lab.ipv4_subnet is not None)
-                        assert (sliver.get_gateway().lab.ipv4 is not None)
-                        assert (interface.labels.vlan is not None)
-
-                    if sliver.get_type() == ServiceType.FABNetv6:
-                        assert (sliver.get_gateway() is not None)
-                        assert (sliver.get_gateway().lab.ipv6_subnet is not None)
-                        assert (sliver.get_gateway().lab.ipv6 is not None)
-                        assert (interface.labels.vlan is not None)
-
-                result = {Constants.PROPERTY_TARGET_NAME: Constants.TARGET_CREATE,
-                          Constants.PROPERTY_TARGET_RESULT_CODE: Constants.RESULT_CODE_OK,
-                          Constants.PROPERTY_ACTION_SEQUENCE_NUMBER: 0}
+            result = {Constants.PROPERTY_TARGET_NAME: Constants.TARGET_CREATE,
+                      Constants.PROPERTY_TARGET_RESULT_CODE: Constants.RESULT_CODE_OK,
+                      Constants.PROPERTY_ACTION_SEQUENCE_NUMBER: 0}
         except Exception as e:
             result = {Constants.PROPERTY_TARGET_NAME: Constants.TARGET_CREATE,
                       Constants.PROPERTY_TARGET_RESULT_CODE: Constants.RESULT_CODE_EXCEPTION,
@@ -133,7 +137,15 @@ class NoOpHandler(HandlerBase):
     def modify(self, unit: ConfigToken) -> Tuple[dict, ConfigToken]:
         result = None
         try:
-            self.get_logger().info(f"Modify invoked for unit: {unit}")
+            self.get_logger().info(f"Modify invoked for unit: {unit} type{unit.get_modified()}")
+            sliver = unit.get_modified()
+
+            if isinstance(sliver, NodeSliver):
+                self.__process_node_sliver(sliver=sliver)
+
+            elif isinstance(sliver, NetworkServiceSliver):
+                self.__process_ns_sliver(sliver=sliver)
+
             result = {Constants.PROPERTY_TARGET_NAME: Constants.TARGET_MODIFY,
                       Constants.PROPERTY_TARGET_RESULT_CODE: Constants.RESULT_CODE_OK,
                       Constants.PROPERTY_ACTION_SEQUENCE_NUMBER: 0}
