@@ -30,7 +30,8 @@ from datetime import datetime
 
 from fim.pluggable import PluggableRegistry
 from fim.slivers.attached_components import AttachedComponentsInfo, ComponentSliver, ComponentType
-from fim.slivers.capacities_labels import Capacities
+from fim.slivers.capacities_labels import Capacities, CapacityHints
+from fim.slivers.instance_catalog import InstanceCatalog
 from fim.slivers.network_node import NodeSliver, NodeType
 
 from fabric_cf.actor.core.apis.abc_authority_proxy import ABCAuthorityProxy
@@ -119,20 +120,26 @@ class BrokerSimplerUnitsPolicyTest(BaseTestCase, unittest.TestCase):
         node_sliver = NodeSliver()
         node_sliver.resource_type = NodeType.VM
         node_sliver.node_id = "test-slice-node-1"
-        cap = Capacities()
-        cap.set_fields(core=4, ram=64, disk=500)
+        cap = Capacities(core=4, ram=64, disk=500)
+        catalog = InstanceCatalog()
+        instance_type = catalog.map_capacities_to_instance(cap=cap)
+        cap_hints = CapacityHints(instance_type=instance_type)
         node_sliver.set_properties(name="node-1", type=NodeType.VM, site="RENC",
-                                   capacities=cap, image_type='qcow2', image_ref='default_centos_8')
+                                   capacities=cap, image_type='qcow2', image_ref='default_centos_8',
+                                   capacity_hints=cap_hints)
         return node_sliver
 
     def build_sliver_with_components(self) -> NodeSliver:
         node_sliver = NodeSliver()
         node_sliver.resource_type = NodeType.VM
         node_sliver.node_id = "test-slice-node-1"
-        cap = Capacities()
-        cap.set_fields(core=4, ram=64, disk=500)
+        cap = Capacities(core=4, ram=64, disk=500)
+        catalog = InstanceCatalog()
+        instance_type = catalog.map_capacities_to_instance(cap=cap)
+        cap_hints = CapacityHints(instance_type=instance_type)
         node_sliver.set_properties(name="node-1", type=NodeType.VM, site="RENC",
-                                   capacities=cap, image_type='qcow2', image_ref='default_centos_8')
+                                   capacities=cap, image_type='qcow2', image_ref='default_centos_8',
+                                   capacity_hints=cap_hints)
         component_sliver = ComponentSliver()
         component_sliver.set_properties(type=ComponentType.SmartNIC, model='ConnectX-6', name='nic1')
         node_sliver.attached_components_info = AttachedComponentsInfo()
@@ -497,14 +504,11 @@ class BrokerSimplerUnitsPolicyTest(BaseTestCase, unittest.TestCase):
         broker.external_tick(cycle=cycle)
         cycle += 1
 
-        units = 1
         start = clock.cycle_start_date(cycle=self.DonateStartCycle)
         end = clock.cycle_end_date(cycle=self.DonateEndCycle - 1)
         sliver = self.build_sliver_with_components()
-
-        cap = Capacities()
-        cap.set_fields(core=33, ram=64, disk=500)
-        sliver.set_properties(capacities=cap)
+        caphint = CapacityHints(instance_type="fabric.c64.m384.d4000")
+        sliver.set_capacity_hints(caphint=caphint)
 
         request = self.get_reservation_for_network_node(start, end, sliver=sliver)
         broker.ticket(reservation=request, callback=proxy, caller=proxy.get_identity())
