@@ -22,7 +22,6 @@ def slices_create_post(body, slice_name, ssh_key, lease_end_time=None):  # noqa:
 
     :rtype: Success
     """
-
     return rc.slices_create_post(body, slice_name, ssh_key, lease_end_time)
 
 
@@ -39,15 +38,17 @@ def slices_delete_slice_iddelete(slice_id):  # noqa: E501
     return rc.slices_delete_slice_iddelete(slice_id)
 
 
-def slices_get():  # noqa: E501
+def slices_get(states=None):  # noqa: E501
     """Retrieve a listing of user slices
 
     Retrieve a listing of user slices # noqa: E501
 
+    :param states: Slice states
+    :type states: List[str]
 
     :rtype: Success
     """
-    return rc.slices_get()
+    return rc.slices_get(states)
 
 
 def slices_modify_slice_idput(body, slice_id):  # noqa: E501
@@ -93,17 +94,19 @@ def slices_renew_slice_idpost(slice_id, new_lease_end_time):  # noqa: E501
     return rc.slices_renew_slice_idpost(slice_id, new_lease_end_time)
 
 
-def slices_slice_idget(slice_id):  # noqa: E501
+def slices_slice_idget(slice_id, graph_format):  # noqa: E501
     """slice properties
 
     Retrieve Slice properties # noqa: E501
 
     :param slice_id: Slice identifier as UUID
     :type slice_id: str
+    :param graph_format: Graph format
+    :type graph_format: str
 
     :rtype: Success
     """
-    return rc.slices_slice_idget(slice_id)
+    return rc.slices_slice_idget(slice_id, graph_format)
 
 
 def slices_status_slice_idget(slice_id):  # noqa: E501
